PRINT N'Creando [dbo].[BatchError]...';


GO
CREATE TABLE [dbo].[BatchError] (
    [VCC]            VARCHAR (50)  NOT NULL,
    [BatchType]      VARCHAR (25)  NOT NULL,
    [BatchTypeId]    VARCHAR (50)  NOT NULL,
    [BatchTypeName]  VARCHAR (50)  NOT NULL,
    [Implementation] VARCHAR (100) NULL,
    [InteractionId]  VARCHAR (250) NULL,
    [Query]          VARCHAR (250) NULL,
    [ErrorFunction]  VARCHAR (100) NULL,
    [ErrorMessage]   VARCHAR (250) NULL,
    [ErrorDetail]    VARCHAR (MAX) NULL,
    [CreatedDate]    DATETIME      NULL,
    [TimeStamp]      DATETIME      NULL
);


GO
PRINT N'Modificando [dbo].[SaveNLU]...';


GO

ALTER PROCEDURE [dbo].[SaveNLU] (
	@VCC Varchar(50) = NULL, 					
	@Name Varchar(50) = NULL,					
	@Culture Varchar(50) = NULL,
	@Description Varchar(50) = NULL,			
	@AppId Varchar(100) = NULL,					
	@SubscriptionKey Varchar(50) = NULL,
	@IsSystemApp BIT = 0,
	@IsPublished BIT = NULL,
	@LastPublishedDate DATETIME = NULL,
	@IsTrained BIT = NULL,
	@NeedTrain BIT = NULL,
	@LastTrainedDate DATETIME = NULL,
	@CreatedDate Datetime = NULL,               
	@CreatedByUserId Varchar(50) = NULL,		
	@LastModifiedDate Datetime = NULL,			
	@LastModifiedByUserId Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON
	
	-- SI LA VARIABLE LLEGA NULL, LA SETTEAMOS COMO 0
	IF @IsSystemApp IS NULL 
		SET @IsSystemApp = 0

	UPDATE [NLU]
	SET [Culture] = @Culture,
		[Description] = @Description,
		[AppId] = @AppId,
		[IsPublished] = CASE WHEN @IsPublished IS NULL THEN [IsPublished] ELSE @IsPublished END,
		[LastPublishedDate] = CASE WHEN @LastPublishedDate IS NULL THEN [LastPublishedDate] ELSE @LastPublishedDate END,
		[IsSystemApp] = CASE WHEN @IsSystemApp IS NULL THEN [IsSystemApp] ELSE @IsSystemApp END,
		[SubscriptionKey] = CASE WHEN @SubscriptionKey IS NULL THEN [SubscriptionKey] ELSE @SubscriptionKey END,
		[IsTrained] = CASE WHEN @IsTrained IS NULL THEN [IsTrained] ELSE @IsTrained END,
		[NeedTrain] = CASE WHEN @NeedTrain IS NULL THEN [NeedTrain] ELSE @NeedTrain END,
		[LastTrainedDate] = CASE WHEN @LastTrainedDate IS NULL THEN [LastTrainedDate] ELSE @LastTrainedDate END,
		-- [CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [NLU] (
			[VCC], [Name], [Culture],
			[Description], [AppId], [SubscriptionKey],
			[IsSystemApp], [CreatedDate], [CreatedByUserId], 
			[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],[CognitiveEngine]
			)
		VALUES (
			@VCC, @Name, @Culture,
			@Description, @AppId, @SubscriptionKey,
			@IsSystemApp, GETUTCDATE(), @CreatedByUserId, 
			@LastModifiedDate, @LastModifiedByUserId, GETUTCDATE(),
			IIF(@IsSystemApp = 1, 'RASA', (SELECT [CognitiveEngine] FROM [dbo].[VCC] WHERE [VCC] = @VCC))
		)
	END
    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[GetBatchErrors]...';


GO
CREATE PROCEDURE [dbo].[GetBatchErrors] (
	@VCC VARCHAR(50) = NULL,
	@BatchType VARCHAR(25) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
) AS 
BEGIN 
    SET NOCOUNT ON

	--
	SELECT BE.[BatchType]					'batchType',
			BE.[BatchTypeId]				'batchTypeId',
			BE.[BatchTypeName]				'batchTypeName',
			BE.[Implementation]				'implementation',
			BE.[InteractionId]				'interactionId',
			BE.[Query]						'query',
			BE.[ErrorFunction]				'errorFunction',
			BE.[ErrorMessage]				'errorMessage',
			BE.[ErrorDetail]				'errorDetail'
		FROM [dbo].[BatchError] BE (NOLOCK)
		WHERE BE.[VCC] = @VCC 
			AND BE.[BatchType] = @BatchType
			AND BE.[BatchTypeId] = @BatchTypeId

	SET NOCOUNT OFF
END
GO
PRINT N'Creando [dbo].[SaveBatchError]...';


GO
CREATE PROCEDURE [dbo].[SaveBatchError] (
	@VCC VARCHAR(50) = NULL,
	@SystemService VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@Implementation VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@Query VARCHAR(250) = NULL,
	@ErrorFunction VARCHAR(100) = NULL,
	@ErrorMessage VARCHAR(250) = NULL,
	@ErrorDetail VARCHAR(MAX) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE REGISTRAR LOS ERRORES QUE PUEDEN OCURRIR DURANTE LA EJECUCION DE LAS COLAS
	SET XACT_ABORT, NOCOUNT ON

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		-- VALIDAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
		IF @VCC IS NULL 
			OR @SystemService IS NULL 
			OR @BatchTypeId IS NULL 
			-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
			RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @SystemService <> 'TRANSCRIPTION' AND @SystemService <> 'SEMANTIC_ANALYSIS' AND @SystemService <> 'COGNITIVE_ANALYSIS'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_SYSTEM_SERVICE', 16, 16)

		-- DECLARAMOS UNA VARIABLE PARA TIPO DE BATCH CORRESPONDIENTE AL BATCHTYPEID
		DECLARE @BATCH_TYPE VARCHAR(50) = NULL

		-- IDENTIFICAMOS EL TIPO BATCH SEGUN EL BATCHTYPEID Y SERVICIO DEL SISTEMA
		IF @SystemService = 'TRANSCRIPTION'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO PROCESS
			IF EXISTS (SELECT 1 FROM [dbo].[Process] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'TRANSCRIPTION'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'SEMANTIC_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		ELSE IF @SystemService = 'COGNITIVE_ANALYSIS'
		BEGIN
			-- VERIFICAMOS SI ES DEL TIPO STUDY
			IF EXISTS (SELECT 1 FROM [dbo].[Study] P (NOLOCK) WHERE [VCC] = @VCC AND [Name] = @BatchTypeId)
				SET @BATCH_TYPE = 'STUDY'

			-- VERIFICAMOS SI ES DEL TIPO EVALUATION_PLAN
			IF EXISTS (SELECT 1 FROM [dbo].[EvaluationPlan] P (NOLOCK) WHERE [Instance] = @VCC AND [ID] = @BatchTypeId)
				SET @BATCH_TYPE = 'EVALUATION_PLAN'
		END
		
		-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
		IF @BATCH_TYPE <> 'TRANSCRIPTION' AND @BATCH_TYPE <> 'STUDY' AND @BATCH_TYPE <> 'EVALUATION_PLAN'
			-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
			RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPE', 16, 16)

		-- SOLO EN CASO DE PLANES @BatchTypeId Y @BatchTypeName SON DIFERENTES
		IF @BatchTypeName IS NULL
			SELECT @BatchTypeName = EP.[Description]
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				 WHERE [Instance] = @VCC AND [ID] = @BatchTypeId

		-- INSERTAMOS EL REGISTRO EN LA TABLA DE ERROR
		INSERT INTO [dbo].[BatchError] (
				[VCC], [BatchType], [BatchTypeId], [BatchTypeName], [Implementation],
				[InteractionId], [Query], [ErrorFunction], [ErrorMessage], [ErrorDetail],
				[CreatedDate], [TimeStamp]
			) VALUES (
				@VCC, @BATCH_TYPE, @BatchTypeId, @BatchTypeName, @Implementation,
				@InteractionId, @Query, @ErrorFunction, @ErrorMessage, @ErrorDetail,
				GETUTCDATE(), GETUTCDATE()
			)

	END TRY
    BEGIN CATCH
        --IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH

	SET XACT_ABORT, NOCOUNT OFF
END
GO
PRINT N'Actualización completada.';


GO
