-- ARCHIVO CON LAS ACTUALIZACIONES DE DATA DE SQL PARA MIGRAR AL NUEVO BUILD DEL NOMBRE DE LA CARPETA
-- DECLARAMOS DOS VARIABLES, UNA CON LA VERSION DE LA QUE PARTIMOS Y OTRA CON LA NUEVA VERSION QUE ESTAMOS APUNTANDO
DECLARE @OLD_DATABASE_BUILD_VERSION VARCHAR(50) = '2.0.4'
DECLARE @NEW_DATABASE_BUILD_VERSION VARCHAR(50) = '2.1.0'

-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
BEGIN TRY
    -- VALIDAMOS QUE LA VERSION EXISTENTE COINCIDE CON NUESTRA NEW_DATABASE_BUILD_VERSION
    IF NOT EXISTS (
        SELECT 1 
            FROM [dbo].[Version] V 
            WHERE V.[BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    )	
        -- LANZAMOS UN MENSAJE DE ERROR INDICANDO QUE LA VERSION ACTUAL NO COINCIDE CON LA OLD_DATABASE_BUILD_VERSION
        RAISERROR('DATABASE_ERROR_INCORRECT_TARGET_VERSION', 16, 16)
        
    -- INICIAMOS LA TRANSACCION
    BEGIN TRANSACTION




    -- AQUI EMPIEZA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION



    -- EN CASO YA EXISTA UN ROL SUPERVISOR, SE LE CAMBIA EL NOMBRE PARA NO TENER CONFLICTO CON EL ROL DEL SISTEMA
    UPDATE [dbo].[Role] 
        SET [ID] = 'quality_supervisor_custom'
        WHERE [ID] = 'quality_supervisor'

    -- LOS USUARIOS QUE TIENEN EL ROL, SE DEBEN ACTUALIZAR A TIPO SUPERVISOR SEGUN LO SEAN EN LA API O SQL, COMO?

    -- ACTUALIZAMOS LOS CATEGORY-PERMISSIONS CUYA POSICION ES MAYOR Y IGUAL A 4
    UPDATE [dbo].[CategoryPermissions] SET [Position] = [Position] + 1 WHERE [Position] >= 4

    -- INSERTAMOS PERMISOS QUE PODRIAN FALTAR EN LAS PLATAFORMAS INSTALADAS POR PRIMERA VEZ CON EL BUILD 0.16.0, EN CASO YA EXISTAN NO SE INSERTAN
    DECLARE RECURRENT_CURSOR CURSOR 
    LOCAL STATIC READ_ONLY FORWARD_ONLY
    FOR 
    -- SELECCIONAMOS LOS VCC EXISTENTES
    SELECT [VCC]
        FROM [dbo].[VCC] (NOLOCK) 

    -- DECLARARAMOS UNA VARIABLE PARA INDICAR EL CAMPO ACTUAL QUE ESTAMOS ACTUALIZANDO
    DECLARE @CURRENT_VCC_TO_UPDATE VARCHAR(50) = ''

    -- ABRIMOS Y RECORREMOS EL ARRAY DE CAMPOS A ACTUALIZAR
    OPEN RECURRENT_CURSOR

    FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    WHILE @@FETCH_STATUS = 0
    BEGIN 

        -- EJECUTAMOS EL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE`

        -- AGREGAMOS LOS ROUTE-PERMISSIONS PARA CONSULTAR SUPERVISORES DESDE PLAN Y PROCESS
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_PROCESS_ADD', N'api/process/allegro/get_allegro_supervisors', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATIONPLAN_ADD', N'api/process/allegro/get_allegro_supervisors', N'api', GETUTCDATE())

        -- AGREGAMOS EL NUEVO ROL DEL SISTEMA
        INSERT [dbo].[Role] ([VCC], [ID], [Description], [Type], [SystemRole], [CreatedDate], [CreatedByUserId], [LastModifiedDate], [LastModifiedByUserId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'quality_supervisor','QUALITY','True', GETUTCDATE(), N'analytic', GETUTCDATE(), N'analytic', GETUTCDATE())

        -- AGREGAMOS EL CATEGORY-PERMISSION PARA SUPERVISOR
        INSERT [dbo].[CategoryPermissions] ([VCC], [Category], [Position], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'CATEG_GROUP_QUALITY_SUPERVISOR', 4 , GETUTCDATE())
        
        -- AGREGAMOS LOS ROL-PERMISSION-GROUPS PARA EL SUPERVISOR
        INSERT [dbo].[RolePermissionsGroup] ([VCC], [Category], [GroupId], [Type], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'CATEG_GROUP_QUALITY_SUPERVISOR', N'PERM_GROUP_SUPERVISOR_INBOX', 'QUALITY', GETUTCDATE())

        -- AGREGAMOS LOS ROL-PERMISSIONS PARA EL SUPERVISOR
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'administrator', N'PERM_GROUP_SUPERVISOR_INBOX', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_AUDITOR_INBOX', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_SUPERVISOR_INBOX', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_CURRENT_USER_EDIT', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_EVALUATION_ADD', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_EVALUATION_EDIT', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_EVALUATIONAUDITOR', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_EVALUATION_VIEW', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_HOME', GETUTCDATE())
        INSERT [dbo].[RolePermission] ([VCC], [RoleId], [GroupId], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, N'quality_supervisor', N'PERM_GROUP_QUALITY_DASHBOARD', GETUTCDATE())

        -- AGREGAMOS LOS ROUTE-PERMISSIONS PARA EL SUPERVISOR
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/interaction/get_not_evaluated_interactions_auditor/', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'speechanalytic/audit/evaluation', N'client', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/interaciontype/get_interactiontypes', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/tag/get_all_tags', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/dispositioncode/evaluation', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/interaction/get_not_evaluated_interactions_auditor/', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/interaction/discard_interaction', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_SUPERVISOR_INBOX', N'api/interaction/recover_interaction', N'api', GETUTCDATE())

        -- AGREGAMOS LAS NUEVAS RUTAS PARA EL GUARDADO Y CONSULTA DE REVISION DE EVALUACION
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATION_ADD', N'api/evaluation/save_evaluation_review', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATION_VIEW', N'api/evaluation/get_evaluation_reviews', N'api', GETUTCDATE())

        -- AGREGAMOS LAS NUEVAS RUTAS PARA LA CONSULTA DE CAMPAIGN-AGENTS
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_PROCESS_ADD', N'api/process/allegro/get_allegro_campaign_agents', N'api', GETUTCDATE())
        INSERT [dbo].[RoutePermission] ([VCC], [ID], [GroupId], [Route], [Level], [TimeStamp]) VALUES (@CURRENT_VCC_TO_UPDATE, NEWID(), N'PERM_GROUP_EVALUATIONPLAN_ADD', N'api/process/allegro/get_allegro_campaign_agents', N'api', GETUTCDATE())

        -- FIN DEL SCRIPT DE INSERT/UPDATE/DELETE PARA CADA VCC EN LA VARIABLE @CURRENT_VCC_TO_UPDATE

        FETCH NEXT FROM RECURRENT_CURSOR INTO @CURRENT_VCC_TO_UPDATE
    END
    CLOSE RECURRENT_CURSOR
    DEALLOCATE RECURRENT_CURSOR
    
    

    -- AQUI TERMINA LA SECCION CON LOS INSERT/UPDATE/DELETE PARA LA NUEVA VERSION


    

    -- TERMINAMOS LA ACTUALIZACION DE DATA ACTUALIZANDO EL BUILDVERSION
    UPDATE [dbo].[Version] 
        SET [BuildVersion] = @NEW_DATABASE_BUILD_VERSION, 
            [IsRegistered] = 0,
            [TimeStamp] = GETUTCDATE() 
        WHERE [BuildVersion] = @OLD_DATABASE_BUILD_VERSION
    PRINT 'UPDATED_DATABASE_BUILD_VERSION'

    -- COMPLETAMOS LA TRANSACCION
    COMMIT TRANSACTION
END TRY
BEGIN CATCH
    IF @@TRANCOUNT > 0 ROLLBACK TRANSACTION

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
    --RETURN -1
END CATCH



