PRINT N'Altering Table [dbo].[Process]...';


GO
ALTER TABLE [dbo].[Process]
    ADD [Retranscription] BIT NULL,
        [Diarization]     BIT NULL,
        [ChannelChange]   BIT NULL;


GO
PRINT N'Altering Procedure [dbo].[GetAudio]...';


GO
ALTER PROCEDURE [dbo].[GetAudio] (
	@VCC Varchar(50) = NULL,
	@ProcessId Varchar(50) = NULL,
	@ID Varchar(100) = NULL,
	@Section NUMERIC(5, 0) NULL,
	@Part NUMERIC(5, 0) NULL
)
AS
BEGIN
	SET NOCOUNT ON

	SELECT TOP 1
		A.[ID]						'id',
		A.[Section]					'section',
		A.[Part]					'part',
		PA.[ProcessId]				'processId',
		A.[Number]					'number',
		A.[Gender]					'gender',
		A.[SilenceTime]				'silenceTime',
		A.[DurationTime]			'durationTime',
		A.[DurationLinguisticTime]	'durationLinguisticTime',
		A.[Category1]				'category1',
		A.[Category2]				'category2',
		A.[Category3]				'category3',
		A.[Description]				'description',
		A.[Campaign]				'campaign',
		A.[Agent]					'agent',
		A.[Type]					'type',
		A.[Init]					'init',
		A.[ChannelsChanged]			'channelsChanged',
		A.[IsTranscribed]			'isTranscribed',
		A.[RelativePath]			'relativePath',
		A.[FileName]				'fileName',
		P.[Retranscription]			'retranscription'
	FROM [Audio] A (NOLOCK)
	LEFT JOIN [ProcessAudio] PA (NOLOCK)
		ON PA.[VCC] = A.[VCC]
			AND A.ID = PA.AudioId 
			AND A.Section = PA.Section 
			AND A.Part = PA.Part
	LEFT JOIN [dbo].[Process] P (NOLOCK)
		ON P.[VCC] = A.[VCC]
			AND PA.[ProcessId] = P.[Name]
	WHERE A.[VCC] = @VCC
		AND (
			(@ProcessId IS NOT NULL AND P.[Name] = @ProcessId)
			OR 
			(@ProcessId IS NULL)
		)
		AND A.[ID] = @ID
		AND A.[Section] = @Section
		AND A.[Part] = @Part
		AND A.[IsTranscribed] = 1
		AND A.[IsCancel] IS NULL
		AND P.[Name] IS NOT NULL
	ORDER BY A.CreatedDate DESC, PA.[CreatedDate] DESC

	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[GetProcessInteractionsTask]...';


GO
ALTER PROCEDURE [dbo].[GetProcessInteractionsTask]
(
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES SINCRONAS(CALL) Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR

		-- Actualiza en el primer momento que se consulta a estos registros, con el valor 1 en el campo IsProcess. Indica que se encuentra utilizado por un proceso.
		UPDATE [dbo].[Audio] SET
			[dbo].[Audio].[IsProcess] = 1,	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
			[dbo].[Audio].[IsCancel] = null, -- Limpiamos el campo isCancel para retomar los audios que fallaron en procesos pasados
			[dbo].[Audio].[ErrorMessage] = NULL
		
		-- Retornamos todas las columnas a listar.
		OUTPUT INSERTED.[VCC]							'vcc',
				PA.[ProcessId]							'processId',
				'CALL'									'interactionType',
				INSERTED.[ID]							'id',
				INSERTED.[Section]						'section',
				INSERTED.[Part]							'part',
				INSERTED.[StartDate]					'startDate',
				INSERTED.[EndDate]						'endDate',
				INSERTED.[Campaign]						'campaign',
				INSERTED.[DispositionCode]				'dispositionCode',
				INSERTED.[Agent]						'agent',
				INSERTED.[Type]							'origin',
				INSERTED.[RelativePath]					'relativePath',
				INSERTED.[FileName]						'fileName',
				INSERTED.[Format]                       'format',
				INSERTED.[MediaInfoTime]                'mediaInfoTime',
				INSERTED.[NeedI6Update]					'needI6Update',
				0										'isDiariced',
				P.[Language]							'language',
				P.[DictionaryId]						'dictionaryId',
				P.Retranscription						'retranscription',
				P.Diarization							'diarization',
				P.ChannelChange							'channelchange',
				E.[Name]								'name',
				E.[Type]								'environmentType',
				E.[Description]							'description',
				E.[FTPDirectory]						'ftpDirectory',
				E.[ApiHost]								'apiHost',
				E.[ApiPort]								'apiPort',
				E.[ApiUser]								'apiUser',
				E.[ApiPassword]							'apiPassword',
				E.[DbDisabled]							'dbDisabled',
				E.[DbServer]							'dbServer',
				E.[DbPort]								'dbPort',
				E.[DbUser]								'dbUser',
				E.[DbPassword]							'dbPassword',
				E.[PbxDisabled]							'pbxDisabled',
				E.[PbxServer]							'pbxServer',
				E.[PbxPort]								'pbxPort',
				E.[PbxUser]								'pbxUser',
				E.[PbxPassword]							'pbxPassword',
				INSERTED.[DurationTime]					'durationTime'
		FROM [dbo].[ProcessAudio] PA (NOLOCK)
		INNER JOIN [dbo].[Audio] A (NOLOCK) 
			ON A.[VCC] = PA.[VCC]
				AND CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[VCC] = A.[VCC]
				AND PA.ProcessId = P.[Name]
		INNER JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = PA.[VCC]
				AND P.[Environment] = E.[Name]
		WHERE A.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(A.[IsProcess], 0) = 0				
					AND 
					ISNULL(A.[IsTranscribed], 0) = 0	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				)
				OR 
				(
					A.[IsProcess] = 1						
					AND 
					A.[IsCancel] = 1
				)
			
				
				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS

		-- ACTUALIZAMOS LOS REGISTROS DE INTERACCIONES ASINCRONAS Y RETORNAMOS LOS DETALLES DE LAS QUE SE VAN A TRANSCRIBIR
		UPDATE [dbo].[AsyncInteraction] 
		SET [dbo].[AsyncInteraction].[IsProcess] = 1,
			[dbo].[AsyncInteraction].[IsCancel] = NULL,
			[dbo].[AsyncInteraction].[ErrorMessage] = NULL
		OUTPUT INSERTED.[VCC]														'vcc',
				P.[Name]															'processId',
				INSERTED.[Channel]													'interactionType',
				INSERTED.[ID]														'id',
				INSERTED.[EndDate]													'endDate',
				INSERTED.[Folder]													'folder',
				INSERTED.[Campaign]													'campaign',
				INSERTED.[DispositionCode]											'dispositionCode',
				ISNULL(INSERTED.[LastTakedAgent], INSERTED.[FirstTakedAgent])		'agent',
				INSERTED.[Initiative]												'origin',
				INSERTED.[TotalMessages]											'totalMessages',
				INSERTED.[RawChar]													'rawChar',
				INSERTED.[ExportedContent]											'exportedContent',
				P.[Language]														'language',
				INSERTED.[FileName]                                                 'fileName',
				'allegro'															'environmentType',
				P.Retranscription													'retranscription'
		FROM [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
		INNER JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
			ON AI.[ID] = PAI.[InteractionId]
				AND AI.[EndDate] = PAI.[EndDate]
		INNER JOIN [dbo].[Process] P (NOLOCK) 
			ON P.[Name] = PAI.[ProcessId] 
		WHERE AI.[VCC] = @VCC
			AND PAI.[ProcessId] = @ProcessId
			AND (
				(
					ISNULL(AI.[IsProcess], 0) = 0
					AND 
					ISNULL(AI.[IsTranscribed], 0) = 0)	-- RETORNAR SOLO LAS INTERACCIONES QUE NO HAYAN SIDO TOMADAS POR OTRO PROCESS
				OR 
				(
					AI.[IsProcess] = 1
					AND 
					AI.[IsCancel] = 1
				)

				
			)					-- RETORNAR SOLO LAS INTERACCIONES QUE HAYAN SIDO TOMADAS Y CANCELADAS POR OTRO PROCESS
	END

	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[SaveProcess]...';


GO

ALTER PROCEDURE [dbo].[SaveProcess] (
	@VCC Varchar(50) = NULL,
	@Name Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@ClientId Varchar(50) = NULL,
	@Type VARCHAR(50),
	@Status Varchar(50) = NULL,
	@StartDate Datetime = NULL,
	@EndDate Datetime = NULL,
	@MinDurationTime Numeric(18, 2) = NULL,
	@MaxDurationTime Numeric(18, 2) = NULL,
	@Language VARCHAR(25) = NULL,
	@DictionaryId VARCHAR(50) = NULL,
	@Environment Varchar(50) = NULL,
	@QueryId Varchar(50) = NULL,
	@QueryDataId Varchar(50) = NULL,
	@QueryDataIdDate Datetime = NULL,
	@BatchScheduleId VARCHAR(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId Varchar(50) = NULL,
	@Retranscription BIT = 0,
	@Diarization BIT = 0,
	@ChannelChange BIT = 0
	)
AS
BEGIN
	SET NOCOUNT ON
	
	UPDATE [Process]
	SET [Description] = @Description,
		[ClientId] = @ClientId,
		[Status] = @Status,
		[Type] = @Type,
		[StartDate] = @StartDate,
		[EndDate] = @EndDate,
		[MinDurationTime] = @MinDurationTime,
		[MaxDurationTime] = @MaxDurationTime,
		[Language] = @Language,
		[DictionaryId] = @DictionaryId,
		[Environment] = @Environment,
		[QueryId] = @QueryId,
		[QueryDataId] = @QueryDataId,
		[QueryDataIdDate] = @QueryDataIdDate,
		[CreatedDate] = CASE WHEN @CreatedDate IS NULL THEN [CreatedDate] ELSE @CreatedDate END,
		[CreatedByUserId] = CASE WHEN @CreatedByUserId IS NULL THEN [CreatedByUserId] ELSE @CreatedByUserId END,
		[LastModifiedDate] = CASE WHEN @LastModifiedDate IS NULL THEN [LastModifiedDate] ELSE @LastModifiedDate END,
		[LastModifiedByUserId] = CASE WHEN @LastModifiedByUserId IS NULL THEN [LastModifiedByUserId] ELSE @LastModifiedByUserId END,
		[TimeStamp] = GETUTCDATE()
		
	WHERE [VCC] = @VCC
    AND [Name] = @Name

    IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [Process] (
			[VCC], [Name], [Description],
			[ClientId], [Status], [Type], [StartDate],
			[EndDate], [MinDurationTime], [MaxDurationTime], 
			[Language], [DictionaryId], [Environment], 
			[QueryId], [QueryDataId], [QueryDataIdDate],
			[BatchScheduleId], 
			[CreatedDate], [CreatedByUserId], [LastModifiedDate], 
			[LastModifiedByUserId], [TimeStamp], [Retranscription], [Diarization], [ChannelChange]
			)
		VALUES (
			@VCC, @Name, @Description,
			@ClientId, @Status, @Type, @StartDate,
			@EndDate, @MinDurationTime, @MaxDurationTime, 
			@Language, @DictionaryId, @Environment, 
			@QueryId, @QueryDataId, @QueryDataIdDate, 
			@BatchScheduleId,
			@CreatedDate, @CreatedByUserId, @LastModifiedDate, 
			@LastModifiedByUserId, GETUTCDATE(), @Retranscription, @Diarization, @ChannelChange
		)
	END
	--En caso de retranscripcion regresar todos los audios a su estado inicial 
	IF @Retranscription = 1
	BEGIN
	  UPDATE A
	  SET A.[IsCancel] = 1,
	  A.[IsTranscribed] = null,
	  A.[init] = null,
	  A.[IsDiariced] = null,
	  A.[ChannelsChanged] = null
	  FROM Audio A inner join ProcessAudio PA on A.id = PA.AudioId
	  WHERE 
	  PA.[VCC] = @VCC AND
	  PA.[ProcessId] = @Name 
	  
	END

    SELECT 1 AS 'result'
    
    SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[GetBillingInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetBillingInteractions] (
	@VCC					VARCHAR(50) = NULL,
	@SecondsPerRequest		DECIMAL(18, 5) = 0,
	@CharsPerPhrase			DECIMAL(18, 5) = 0,
	@Channel				VARCHAR(25) = NULL,
	@Retranscription		BIT = 0
	
)
AS
BEGIN
	
	-- SEGUN EL TIPO DE CANAL DEFINIMOS LA FUNCION
	IF @Channel = 'CALL'
	BEGIN
		SELECT SUM(CASE WHEN A.[IsTranscribed] = 1 AND @Retranscription = 0 THEN 1 ELSE 0 END)									'alreadyTranscribedAudio',
				SUM(CASE WHEN A.[IsTranscribed] = 1 AND @Retranscription = 0 THEN IT.[AttentionTime] ELSE 0 END)					'alreadyTranscribedDurationTime',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN 1 ELSE 0 END)															'inProcessAudio',
				SUM(CASE WHEN (A.[IsProcess] = 1 
								AND A.[IsTranscribed] IS NULL 
								AND A.[IsCancel] IS NULL) 
							THEN IT.[AttentionTime] ELSE 0 END)											'inProcessDurationTime',
				@Channel																				'interactionType',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)) 
							THEN 1 ELSE 0 END)															'notTranscribedAudio',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)) 
							THEN IT.[AttentionTime] ELSE 0 END)											'notTranscribedDurationTime',
				SUM(CASE WHEN A.[IsTranscribed] = 1  
								AND A.[TotalPhrases] IS NOT NULL
							THEN A.[TotalPhrases] ELSE 0 END)											'totalPhrases',
				SUM(CASE WHEN (A.[IsProcess] IS NULL 
								OR (A.[IsProcess] = 1 
									AND A.[IsCancel] = 1)
								OR (A.[TotalPhrases] IS NULL)) 
							THEN (IT.[AttentionTime] / @SecondsPerRequest) ELSE 0 END)					'totalRawPhrases',
				SUM(IT.[AttentionTime] / @SecondsPerRequest)											'averageModelRequest' 
			FROM [#InteractionsTemp] IT
			LEFT JOIN [dbo].[Audio] A (NOLOCK) 
				ON A.[ID] = IT.[InteractionId]
					AND A.[Section] = IT.[Section]
					AND A.[Part] = IT.[Part] 
				WHERE A.[VCC] = @VCC
	END
	ELSE
	BEGIN
		-- DECLARAMOS UNA VARIABLE PARA PARA EL TOTALDE RESULTADOS
		DECLARE @TOTAL_INTERACTIONS INT = 0

		-- SETTEAMOS EL NUMERO DE REGISTROS A LA VARIABLE DE TOTAL
		SELECT @TOTAL_INTERACTIONS = COUNT(*) FROM [#InteractionsTemp]

		IF @TOTAL_INTERACTIONS = 0 
		BEGIN
			-- SI NO EXISTEN RESULTADOS EN HD LLENAMOSUN RESULTADOS CON 0
			SELECT @Channel																					'interactionType',
					0																						'totalInteractionDetails',
					0																						'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					0																						'notTranscribedInteraction',
					0																						'totalPhrases',
					0																						'totalRawChars',
					0																						'totalRawPhrases'
		END 
		ELSE
		BEGIN
			-- CRUZAMOS LA TABLA TEMPORAL DE INTERACCIONES ASINCRONAS CON LA TABLA LOCAL INTERACTION PARA LAS INTERACCIONES ASINCRONAS YA REGISTRADAS
			SELECT ISNULL(IT.[Channel], @Channel)															'interactionType',
					COUNT(*)																				'totalInteractionDetails',
					SUM(CASE WHEN (AI.[VCC] IS NOT NULL 
						AND AI.[IsTranscribed] = 1) THEN 1 ELSE 0 END)				'alreadyTranscribedInteraction',
					0																						'inProcessInteraction',
					SUM(CASE WHEN (AI.[VCC] IS NULL 
						OR AI.[IsTranscribed] <> 1) THEN 1 ELSE 0 END)										'notTranscribedInteraction',
					SUM(ISNULL(AI.[TotalPhrases], 0))														'totalPhrases',
					-- CUANDO TENEMOS VALIDPHRASES, YA NO CONTAMOS LAS RAWCHAR 
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							ISNULL(AI.[RawChar], ISNULL(IT.[rawChar], 0))
						)
						ELSE 0 END
					)																						'totalRawChars',
					SUM(
						CASE WHEN (AI.[TotalPhrases] IS NULL 
								OR AI.[TotalPhrases] = 0)
						THEN (
							-- SI RAWCHAR ES NULL, SE DEBE VALUAR COMO MINIMO 1 FRASE(@CharsPerPhrase)
							-- CEILING(ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], @CharsPerPhrase)) * 1.00 / @CharsPerPhrase)
							CEILING(ISNULL(AI.[RawChar], ISNULL(IT.[RawChar], 0)) * 1.00 / @CharsPerPhrase)
						)
						ELSE 0 END
					)																						'totalRawPhrases' 
				FROM [#InteractionsTemp] IT
				LEFT JOIN [dbo].[AsyncInteraction] AI 
					ON IT.[VCC] = AI.[VCC]
						AND IT.[Channel] = AI.[Channel]
						AND IT.[Campaign] = AI.[Campaign]
						AND IT.[InteractionId] = AI.[ID]
						AND IT.[EndDate] = AI.[EndDate]
					--WHERE AI.[VCC] = @VCC
				GROUP BY IT.[VCC],
							IT.[Channel]

		END
	END

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [#InteractionsTemp] 
END
GO
PRINT N'Refreshing Procedure [dbo].[BulkInteractionProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkInteractionProcess]';


GO
PRINT N'Refreshing Procedure [dbo].[BulkProgress]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[BulkProgress]';


GO
PRINT N'Refreshing Procedure [dbo].[DeleteProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[DeleteProcess]';


GO
PRINT N'Refreshing Procedure [dbo].[EvaluateProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[EvaluateProcessStatus]';


GO
PRINT N'Refreshing Procedure [dbo].[FinishedBatchClose]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[FinishedBatchClose]';


GO
PRINT N'Refreshing Procedure [dbo].[GetAllegroBillingInteractionsForEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAllegroBillingInteractionsForEvaluationPlan]';


GO
PRINT N'Refreshing Procedure [dbo].[GetAudioNavigatorInteractions]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudioNavigatorInteractions]';


GO
PRINT N'Refreshing Procedure [dbo].[GetAudiosByProcessId]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudiosByProcessId]';


GO
PRINT N'Refreshing Procedure [dbo].[GetAudiosProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetAudiosProcess]';


GO
PRINT N'Refreshing Procedure [dbo].[GetBatchDetail]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetBatchDetail]';


GO
PRINT N'Refreshing Procedure [dbo].[GetBatchScheduleExecutionsByBatchType]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetBatchScheduleExecutionsByBatchType]';


GO
PRINT N'Refreshing Procedure [dbo].[GetCleanerData]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetCleanerData]';


GO
PRINT N'Refreshing Procedure [dbo].[GetDictionaryUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetDictionaryUsage]';


GO
PRINT N'Refreshing Procedure [dbo].[GetEvaluationPlan]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetEvaluationPlan]';


GO
PRINT N'Refreshing Procedure [dbo].[GetExecuteTemplateProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetExecuteTemplateProcess]';


GO
PRINT N'Refreshing Procedure [dbo].[GetInteractionsResult]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionsResult]';


GO
PRINT N'Refreshing Procedure [dbo].[GetInteractionTranscription]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetInteractionTranscription]';


GO
PRINT N'Refreshing Procedure [dbo].[GetLinguisticProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetLinguisticProcessStatus]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcess]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcess]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessByName]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessByName]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessByStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessByStatus]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessEvaluationPlanTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessEvaluationPlanTask]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessTask]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessTask]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessUsage]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessUsage]';


GO
PRINT N'Refreshing Procedure [dbo].[GetProcessValidDurationTime]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetProcessValidDurationTime]';


GO
PRINT N'Refreshing Procedure [dbo].[GetStudyResultSummary]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetStudyResultSummary]';


GO
PRINT N'Refreshing Procedure [dbo].[SaveBatchError]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchError]';


GO
PRINT N'Refreshing Procedure [dbo].[SaveBatchStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveBatchStatus]';


GO
PRINT N'Refreshing Procedure [dbo].[SaveProcessStatus]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveProcessStatus]';


GO
PRINT N'Update complete.';


GO