
PRINT N'Creating Table [dbo].[EvaluationResultEfectivity]...';


GO
CREATE TABLE [dbo].[EvaluationResultEfectivity] (
    [VCC]                       VARCHAR (50)  NULL,
    [EfectivityPlanId]          VARCHAR (50)  NULL,
    [EvaluationPlanId]          VARCHAR (50)  NULL,
    [InteractionId]             VARCHAR (250) NULL,
    [AgentId]                   VARCHAR (50)  NULL,
    [AbilityEvaluationFormatId] VARCHAR (50)  NULL,
    [AuditorId]                 VARCHAR (50)  NULL,
    [Efectivity]                VARCHAR (50)  NULL,
    [EfectivityStatus]          VARCHAR (50)  NULL,
    [CreatedDate]               DATETIME      NULL,
    [LastModifiedDate]          DATETIME      NULL
);


GO
PRINT N'Altering Procedure [dbo].[GetAgentsFromEvaluation]...';


GO
-- ESTE SP RETORNA LOS AGENTES ASOCIADOS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetAgentsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0 
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdAgent]							''userId'',
						IEP.[IdCampaign]						''campaignId'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] 
			INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EvaluationPlanId],[AuditorId] FROM [dbo].[EvaluationResultEfectivity] 
						 WHERE [EfectivityStatus] IN( ''' + 'CREATED'+''''+','+ ''''+ 'DRAFT'+''''+ ')' +

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdAgent] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- FILTRAMOS SEGUN EL VALOR DE CAMPAIGNS
	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
	BEGIN
		SET @SQL_FILTER += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
        SET @SQL_FILTER_EFECTIVITY += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	END 

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Altering Procedure [dbo].[GetAuditorEvaluationPlanEvaluation]...';


GO
ALTER PROCEDURE [dbo].[GetAuditorEvaluationPlanEvaluation] (
	@Instance Varchar(50) = NULL,
	@AuditorId Varchar(50) = NULL,
	@EvaluationPlanId Varchar(50) = NULL,
	@InteractionId Varchar(250) = NULL,
	@InteractionType Varchar(25) = NULL,
	@EfectivityPlanId Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	IF (ISNULL(@EfectivityPlanId,'') = '' OR @EfectivityPlanId = '' )
	BEGIN

		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				EP.[Evaluation_Mode]				'evaluation_mode',
				AEP.[IdAuditor]						'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.ID = AEP.IdEvaluationPlan
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND IEP.[IdAgent] = AEP.[IdAgent]		
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND AEP.[IdAuditor] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType;
		END
	ELSE
		BEGIN
		
		SELECT AEP.[IdEvaluationPlan]				'evaluationPlanId', 
				ERE.[EfectivityPlanId]				'efectivityPlanId',
				EP.[Evaluation_Mode]				'evaluation_mode',
				ERE.[AuditorId]					    'auditorId', 
				IEP.[IdAgent]						'agentId',
				IEP.[AgentName]						'agentName',
				AEP.[IdInteraction]					'interactionId', 
				AEP.[Completed]						'evaluationCompleted', 
				EP.[Description]					'evaluationPlanDescription',
				EP.[IdEvaluationFormat]				'evaluationFormatId',
				AEP.[Completed]						'completed',
				AEP.[Status]						'status',
				AEP.[StatusDescription]				'statusDescription'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.ID = AEP.IdEvaluationPlan
			INNER JOIN (SELECT DISTINCT [VCC],[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
						WHERE EfectivityPlanId = @EfectivityPlanId AND AuditorId = @AuditorId
			) AS ERE
			ON AEP.[Instance] = ERE.[VCC]
			AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
			AND AEP.[IdInteraction] = [ERE].[InteractionId]			

			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[InteractionType] = AEP.[InteractionType]
					AND IEP.[IdAgent] = AEP.[IdAgent]		
			WHERE AEP.[Instance] = @Instance 
				AND AEP.[IdEvaluationPlan] = @EvaluationPlanId 
				AND ERE.[AuditorId] = @AuditorId 
				AND AEP.[IdInteraction] = @InteractionId
				AND AEP.[InteractionType] = @InteractionType;

		END


	SET NOCOUNT OFF
END
GO
PRINT N'Altering Procedure [dbo].[GetCampaignsFromEvaluation]...';


GO
-- ESTE SP RETORNA LAS CAMPANAS ASOCIADAS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetCampaignsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@SearchType				VARCHAR(50) = 'HISTORY',
	@EfectivityMode			BIT = 0
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdCampaign]						''id'',
						IEP.[IdCampaign]						''description'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY +=	'
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
			INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EvaluationPlanId],[AuditorId] FROM [dbo].[EvaluationResultEfectivity] 
						 WHERE [EfectivityStatus] IN( ''' + 'CREATED'+''''+','+ ''''+ 'DRAFT'+''''+ ')' +

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdCampaign] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
		
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Altering Procedure [dbo].[GetDispositionCodesFromEvaluation]...';


GO
ALTER PROCEDURE [dbo].[GetDispositionCodesFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0 

) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'',
						IEP.[IdCampaign]						''campaignId'', 
						IEP.[ManagementResult]					''dispositionTreePath'' '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	
	SET @SQL_FROM_EFECTIVITY +='
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] 
				INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EvaluationPlanId],[AuditorId] FROM [dbo].[EvaluationResultEfectivity] 
						 WHERE [EfectivityStatus] IN( ''' + 'CREATED'+''''+','+ ''''+ 'DRAFT'+''''+ ')' +

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	


	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND IEP.[ManagementResult] IS NOT NULL '
    SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' 
				AND IEP.[ManagementResult] IS NOT NULL '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdCampaign] ASC, IEP.[ManagementResult] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
        SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- FILTRAMOS SEGUN EL VALOR DE CAMPAIGNS
	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
	BEGIN
		SET @SQL_FILTER += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
        SET @SQL_FILTER_EFECTIVITY += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	END 

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Altering Procedure [dbo].[GetEvaluationResults]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationResults] (
	@VCC VARCHAR(50) = NULL, 
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL,
	@AuditorId VARCHAR(50) = NULL,
	@EfectivityPlanId VARCHAR(50) = NULL
) 
AS
BEGIN
	SET NOCOUNT ON

	-- SP PARA SOLICITAR LOS RESULTADOS DE LA EVALUACION DE UNA INTERACCION POR VCC, PLAN Y AUDITOR 
	IF(@EfectivityPlanId IS NULL OR @EfectivityPlanId = '' )
	BEGIN
		SELECT ER.[IdAbility]							'idAbility',
				A.[Type]								'abilityType',
				ER.[Qualification]						'qualification',
				ER.[ScoreDescription]					'scoreDescription',
				ER.[Comment]                            'comments',
				ER.[Conditional]                        'conditional',
				ER.[EvaluationDate]						'evaluationDate',
				ER.[AbilityOrder]						'abilityOrder',
				ER.[LastModifiedByUserId]				'lastModifiedByUserId',
				ER.[LastModifiedDate]					'lastModifiedDate'
			FROM [dbo].[EvaluationResult] ER (NOLOCK)
			LEFT JOIN [dbo].[Ability] A (NOLOCK) 
				ON A.[Instance] = ER.[Instance]
					AND A.[ID] = ER.[IdAbility]
			WHERE ER.[Instance] = @VCC 
				AND ER.[IdEvaluationPlan] = @EvaluationPlanId
				AND ER.[IdInteraction] = @InteractionId
				AND ER.[IdAuditor] = @AuditorId
			ORDER BY ER.[AbilityOrder] ASC
	  END
	  ELSE
	  BEGIN
	  
		 SELECT ER.[IdAbility]							'idAbility',
				A.[Type]								'abilityType',
				ER.[Qualification]						'qualification',
				ER.[ScoreDescription]					'scoreDescription',
				ER.[Comment]                            'comments',
				ER.[Conditional]                        'conditional',
				ER.[EvaluationDate]						'evaluationDate',
				ER.[AbilityOrder]						'abilityOrder',
				ER.[LastModifiedByUserId]				'lastModifiedByUserId',
				ER.[LastModifiedDate]					'lastModifiedDate',
				ERE.[EfectivityPlanId]					'efectivityPlanId',
				ERE.[Efectivity]						'efectivity',
				ERE.[EfectivityStatus]					'efectivityStatus',
				ERE.[AbilityEvaluationFormatId]			'abilityEvaluationFormatId'
			
			FROM [dbo].[EvaluationResult] ER (NOLOCK)	
			INNER JOIN [dbo].[EvaluationResultEfectivity] ERE (NOLOCK)
				ON  ER.[Instance] = 	ERE.[VCC] AND
					ER.[IdInteraction] = ERE.[InteractionId] AND	
					ER.[IdAgent] =	ERE.[AgentId] AND
					ER.[IdEvaluationPlan] =	ERE.[EvaluationPlanId] AND
					ER.[IdAbilityEvaluationFormat] = ERE.[AbilityEvaluationFormatId] AND				
					ERE.[EfectivityStatus] IN ('CREATED','DRAFT')
			LEFT JOIN [dbo].[Ability] A (NOLOCK) 
				ON A.[Instance] = ER.[Instance]
					AND A.[ID] = ER.[IdAbility]
			WHERE ER.[Instance] = @VCC 
				AND ER.[IdEvaluationPlan] = @EvaluationPlanId
				AND ER.[IdInteraction] = @InteractionId
				AND ERE.[AuditorId] = @AuditorId
				AND ERE.EfectivityPlanId = @EfectivityPlanId
			ORDER BY ER.[AbilityOrder] ASC


	  END

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 1ER NIVEL
	SELECT ET.[AbilityId]							'abilityId',
			ET.[ScoreId]							'scoreId',
			ET.[ID]									'id',
			ET.[IsChecked]							'isChecked'
		FROM [dbo].[EvaluationTipification] ET (NOLOCK)
		WHERE ET.[VCC] = @VCC 
			AND ET.[EvaluationPlanId] = @EvaluationPlanId
			AND ET.[InteractionId] = @InteractionId
			AND ET.[AuditorId] = @AuditorId

	-- BUSCAMOS LOS RESULTADOS DE LAS TIPIFICACIONES DE 2DO Y 3ER NIVEL
	SELECT ETI.[ScoreId]								'scoreId',
			ETI.[TipificationId]						'tipificationId',
			ETI.[ID]									'id',
			ETI.[IsChecked]							'isChecked' 
		FROM [dbo].[EvaluationTipificationItem] ETI (NOLOCK)
		WHERE ETI.[VCC] = @VCC 
			AND ETI.[EvaluationPlanId] = @EvaluationPlanId
			AND ETI.[InteractionId] = @InteractionId
			AND ETI.[AuditorId] = @AuditorId
		
	SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[GetEfectivityPlans]...';


GO
CREATE  PROCEDURE [dbo].[GetEfectivityPlans] (
@VCC                Varchar(50) = NULL,
@SearchCriteria     Varchar(50) = NULL,
@SearchExpression   Varchar(50) = NULL
)
AS
BEGIN
SET NOCOUNT ON

	--SELECCIONAMOS TODOS LOS PLANES AUTOMATICOS EXISTENTES PARA GENERAR  LA MUESTRA  A PARTIR DEL PLAN DE EVALUACION

    SELECT
			e.[ID]							'id',
			e.[Modality]					'modality',
			e.[DateFin]						'dateFin',
			e.CreatedDate					'createdDate',
			e.CreatedByUserId				'createdByUserId',
			e.LastModifiedDate				'lastModifiedDate',
			e.LastModifiedByUserId			'lastModifiedByUserId',
			e.Description					'description',
			e.IdEvaluationFormat            'idEvaluationFormat',
			e.Enabled						'enabled',
			e.Status						'status',
			e.Evaluation_Mode				'evaluation_mode',
			e.processId    				    'processId',
			ef.templateId    				'templateId',
			COUNT(a.IdInteraction)			'totalEvaluations',		
			COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)					'completedEvaluations',
			(
				(
					CAST(
						COUNT(DISTINCT CASE a.[Completed] WHEN 1 THEN a.[IdInteraction] ELSE NULL END)
						+ 
						COUNT(DISTINCT CASE a.[Status] WHEN 0 THEN a.[IdInteraction] ELSE NULL END)
					 AS NUMERIC(6,2)) 
				)
				/
				CASE COUNT(DISTINCT a.[IdInteraction]) WHEN 0 THEN 1 ELSE COUNT(DISTINCT a.[IdInteraction]) END 
			) * 100																							'completedPercentage',
			e.[Percentage]					'percentage',
			e.[StatusDescription]			'statusDescription',
			e.[BatchStatus]					'batchStatus'		
		FROM EvaluationPlan e (NOLOCK)
		LEFT JOIN AuditorEvaluationPlan a (NOLOCK) 
			ON a.[Instance] = e.[Instance]
				AND a.[IdEvaluationPlan] = e.[ID]
		LEFT JOIN EvaluationFormat ef (NOLOCK)
			ON ef.[Instance] = e.[Instance]
				AND ef.[ID] = e.[IdEvaluationFormat]
        
		WHERE e.Instance = @VCC
			AND e.Evaluation_Mode IN ('A','X')
			AND e.Status = '7'			
		GROUP BY e.[ID],e.[Modality],e.[DateFin],e.CreatedDate,e.CreatedByUserId,
				 e.LastModifiedDate,e.LastModifiedByUserId,e.Description,e.IdEvaluationFormat,
				 e.Enabled, e.Status, e.Evaluation_Mode,e.processId,ef.templateId, 
				 e.Percentage, e.StatusDescription, e.[BatchStatus]	
		
		
		--SELECCIONAR PLANES DE EFECTIVIDAD GENERADOS PARA LA GRILLA DE ADMINISTRACION 

		;WITH Temp_EfectivityPlan AS (

		SELECT DISTINCT 
		[EfectivityPlanId],[EvaluationPlanId],[InteractionId],[EfectivityStatus] 
		FROM dbo.[EvaluationResultEfectivity] (NOLOCK)
		WHERE [VCC] = @VCC
		),
		Temp_EfectivityPlan_Result  AS (
		SELECT [EfectivityPlanId],[EvaluationPlanId],COUNT(InteractionId)  'total',
		COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END)					'completedEvaluations',
		CAST(CAST(COUNT(DISTINCT CASE WHEN [EfectivityStatus] = 'COMPLETED' THEN [InteractionId] ELSE NULL END) AS DECIMAL(10,2))*100
		/
		CAST(COUNT(InteractionId) AS DECIMAL(10,2)) AS DECIMAL)															'completedPercentage'
		
        FROM Temp_EfectivityPlan EP1		

		WHERE  ISNULL(EfectivityPlanId, '') LIKE CASE WHEN @SearchCriteria = 'description' THEN '%' + @SearchExpression + '%' ELSE '%' END
			
		
		GROUP BY  EfectivityPlanId,EvaluationPlanId
		)		

		SELECT DISTINCT 
		TER.[EfectivityPlanId] 'id',
		TER.[EvaluationPlanId] 'evaluationPlanId',
		TER.[total] 'total',
		TER.[completedEvaluations] 'completedEvaluations',
		TER.[completedPercentage]	'completedPercentage',	
		TE.[CreatedDate] 'createdDate', 
		CASE WHEN TER.[completedPercentage] = 100 THEN 'COMPLETED' 
			 WHEN TER.[completedPercentage] = 0 THEN 'CREATED' ELSE 'IN_PROCESS' END  'statusDescription',
		TE.[AuditorId]	'auditorId'
		
		FROM Temp_EfectivityPlan_Result TER 
		INNER JOIN (SELECT DISTINCT [EfectivityPlanId],[EvaluationPlanId],[CreatedDate],[AuditorId] FROM dbo.[EvaluationResultEfectivity]
					WHERE VCC = @VCC) AS TE ON 
		TER.EfectivityPlanId = TE.EfectivityPlanId
	    AND TER.EvaluationPlanId = TE.EvaluationPlanId
		

    SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[GetEfectivityPlansAuditor]...';


GO

CREATE PROCEDURE [dbo].[GetEfectivityPlansAuditor] (
	@Instance VARCHAR(50) = NULL,
	@UserId VARCHAR(50) = NULL,
	@Campaigns VARCHAR(MAX) = NULL,	
	@EvaluationPlans VARCHAR(MAX) = NULL,	
	@Completed BIT = NULL,
	@UserFunction VARCHAR(50) = NULL,	
	@EfectivityPlans VARCHAR(MAX) = NULL
)
AS
BEGIN
	SET NOCOUNT ON
	
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''	
	DECLARE @SQL_FILTER VARCHAR(MAX) = ''	
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''	
	DECLARE @SQL_SELECT_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM_2 VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER_2 VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA_2 VARCHAR(MAX) = ''

	--VARIABLES PARA EFECTIVIDAD
	DECLARE @SQL_SELECT_1_EFECTIVITY VARCHAR(MAX) = ''
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = ''
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA_EFECTIVITY VARCHAR(MAX) = ''
	

	-- ARMAMOS EL SELECT DE LA QUERY
    
	SET @SQL_SELECT_1_EFECTIVITY += '
		SELECT EP.[ID]																								''id'', 
				ERE.[EfectivityPlanId]																				''efectivityPlanId'',
				EP.[Description]																					''description'',				
				EP.[IdEvaluationFormat]																				''idEvaluationFormat'',
				COUNT(DISTINCT ERE.[InteractionId])																	''totalInteraction'',
				COUNT(DISTINCT CASE ERE.[EfectivityStatus]  WHEN ''COMPLETED'' THEN ERE.[InteractionId] ELSE NULL END)					''completedInteraction'',
				COUNT(DISTINCT ERE.[InteractionId]) -COUNT(DISTINCT CASE ERE.[EfectivityStatus]  WHEN ''COMPLETED'' THEN ERE.[InteractionId] ELSE NULL END)  ''pendingInteraction''
				'
				

    
	SET @SQL_FROM_EFECTIVITY +='
			FROM [EvaluationPlan] EP (NOLOCK)
			INNER JOIN [AuditorEvaluationPlan] AEP (NOLOCK)
				ON (AEP.[Instance] = EP.[Instance] 
					AND AEP.[IdEvaluationPlan] = EP.[ID])
			INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EfectivityPlanId],[EvaluationPlanId],[AuditorId],[EfectivityStatus] FROM [dbo].[EvaluationResultEfectivity] 
						 WHERE [VCC] =' +''''+ @Instance +'''' +

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @UserFunction = 'auditor'
	BEGIN
		SET @SQL_FROM_EFECTIVITY += '
					AND ERE.[AuditorId] = ''' + @UserId + ''''
	END
	ELSE IF (@UserFunction = 'admin')
	BEGIN	
		SET @SQL_FROM_EFECTIVITY += ')'
	END
	ELSE 
	BEGIN		
		SET @SQL_FROM_EFECTIVITY += '
					AND ERE.[AuditorId] = ''' + @UserId + ''') '
	END 

	
     SET @SQL_FILTER_EFECTIVITY += '
			WHERE EP.[Instance] = ''' + @Instance + '''				
				AND EP.[Enabled] = 1 
				AND (
					(
						EP.[Evaluation_Mode] = ''X'' 
						AND 
						(
							EP.[Status] = 7
							OR
							EP.[Status] = 8
						)
					)
					OR
					(EP.[Evaluation_Mode] = ''A'')
				) '
				
					
				

	IF (@Campaigns IS NOT NULL AND @Campaigns <> '')
	BEGIN
		
		SET @SQL_FILTER_EFECTIVITY += '
				AND EP.[IdEvaluationFormat] IN (
					SELECT CEF.[IdEvaluationFormat] FROM CampaignEvaluationFormat CEF 
						WHERE CEF.[Instance] = ''' + @Instance + '''
							AND CEF.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','',''))) '
	END

	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans <> '') SET @SQL_FILTER += 'AND EP.[ID] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@EfectivityPlans IS NOT NULL AND @EfectivityPlans <> '') SET @SQL_FILTER_EFECTIVITY += 'AND ERE.[EfectivityPlanId] IN (SELECT Value FROM [dbo].[split](''' + @EfectivityPlans + ''','','')) '
	
	-- VARIABLE PARA FILTRAR SOLO LOS REGISTROS DE AUDITOREVALUATIONPLAN CON [COMPLETED] = 1
	IF (@Completed = 1)
	BEGIN
		SET @SQL_FILTER += 'AND AEP.[Completed] = 1 '
		SET @SQL_FILTER_2 = ' '
	END
	ELSE 
	BEGIN
		-- SI NO LLEGA UN VALOR PARA EVALUATION PLANS, BUSCAMOS SOLO LOS QUE TIENEN INTERACCIONES PENDIENTES
		IF (@EfectivityPlans IS NULL OR @EfectivityPlans = '')
		BEGIN
		
			SET @SQL_FILTER_2 = 'WHERE X.[pendingInteraction] > 0 '
		END
	END
	

	
	SET @SQL_EXTRA_EFECTIVITY += '
			GROUP BY EP.[ID],
						ERE.[EfectivityPlanId],
						EP.[Modality],
						EP.[DateFin],
						EP.[CreatedDate],
						EP.[IdEvaluationFormat],
						EP.[Description]'

		SET @SQL_SELECT_1_EFECTIVITY += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA_EFECTIVITY
		
		SET @SQL_SELECT_2 = 'SELECT * '
		SET @SQL_FROM_2 = 'FROM (' + @SQL_SELECT_1_EFECTIVITY + ') AS X '
	
		SET @SQL_EXTRA_2 = 'ORDER BY X.[Description] ASC'

		SET @SQL_SELECT_2 += @SQL_FROM_2 + @SQL_FILTER_2 + @SQL_EXTRA_2

		--PRINT @SQL_SELECT_2;
		EXEC (@SQL_SELECT_2)

	
	
	SET NOCOUNT OFF
	
END
GO
PRINT N'Creating Procedure [dbo].[GetEvaluationResultEfectivitySummary]...';


GO
CREATE PROCEDURE [dbo].[GetEvaluationResultEfectivitySummary](
		@VCC VARCHAR(50),
		@EfectivityPlanId VARCHAR(50)
)
AS
BEGIN
		;WITH TEMP_EVALUATIONREF AS (
		SELECT DISTINCT ERE.[VCC],ER.[IdInteraction],ER.[IdEvaluationPlan],ER.[ScoreDescription],ERE.[Efectivity]
		,A.[Title] 
		FROM dbo.[EvaluationResult] ER (NOLOCK)
		INNER JOIN dbo.[EvaluationResultEfectivity] ERE (NOLOCK)
 
		ON ERE.[VCC] = ER.[Instance]
		AND ERE.[InteractionId] = ER.[IdInteraction]
		AND ERE.[AgentId] = ER.[IdAgent]
		AND ERE.[EvaluationPlanId] = ER.[IdEvaluationPlan] 
		AND ERE.[AbilityEvaluationFormatId] = ER.[IdAbilityEvaluationFormat]		
		INNER JOIN dbo.[Ability] A ON 
		ER.[IdAbility] = A.[ID]
		AND ER.[Instance] = A.[Instance]
		WHERE
		 ER.[Instance] = @VCC		
		 AND ERE.[EfectivityPlanId] = @EfectivityPlanId
		)

		SELECT [VCC] 'vcc',[title] 'ability',
		ISNULL(SUM(CASE WHEN [Efectivity] = 1 THEN 1 ELSE 0 END),0) AS 'correcto' ,
		ISNULL(SUM(CASE WHEN [Efectivity] = 0 THEN 1 ELSE 0 END ),0) AS 'incorrecto' 
		FROM TEMP_EVALUATIONREF
		GROUP BY  VCC,title


END
GO
PRINT N'Creating Procedure [dbo].[GetFiltersFromEvaluation]...';


GO
CREATE PROCEDURE [dbo].[GetFiltersFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0
) 
AS
BEGIN
	EXEC [dbo].[GetCampaignsFromEvaluation] @VCC, @UserId,@SearchType,@EfectivityMode
	EXEC [dbo].[GetAgentsFromEvaluation] @VCC, @UserId,@Campaigns,@SearchType,@EfectivityMode
	EXEC [dbo].[GetDispositionCodesFromEvaluation]  @VCC, @UserId,@Campaigns,@SearchType,@EfectivityMode
	EXEC [dbo].[GetInteractionTypes] @VCC,null,null	
END
GO
PRINT N'Creating Procedure [dbo].[GetNotEvaluatedInteractionsEfectivityAuditor]...';


GO
-- ESTE SP MUETRA LA LISTA DE EVALUACIONES PENDIENTES PARA UN AUDITOR
CREATE PROCEDURE [dbo].[GetNotEvaluatedInteractionsEfectivityAuditor] (
	@Instance Varchar(50) = NULL, 
	@UserId Varchar(50) = NULL,
	@IdCampaigns VARCHAR(MAX) = NULL,
	@IdAgents Varchar(MAX) = NULL,
	@EvaluationPlans Varchar(MAX) = NULL,
	@InteractionTypes Varchar(100) = NULL,
	@InteractionResults Varchar(MAX) = NULL,
 	@EvaluationDateTo   VARCHAR(MAX) = '2050-01-01T23:59:59',
	@EvaluationStatus BIT = 1,
 	@InteractionIds     VARCHAR(MAX) = NULL,
	@ContactAddress VARCHAR(300) = NULL,
	@EfectivityPlans Varchar(MAX) = NULL
	
	)
AS
BEGIN
	SET NOCOUNT ON
	DECLARE @USER_ROLE VARCHAR(50) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''	
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = ''
	DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART VARCHAR(MAX) = ''
	DECLARE @FILTERS_FIXED_PART_EFECTIVITY VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''

	-- IDENTIFICAMOS EL ROL DEL USUARIO
	SELECT @USER_ROLE = U.[Role]
		FROM [dbo].[User] U (NOLOCK)
		WHERE U.[VCC] = @Instance
			AND U.[ID] = @UserId

	-- EMULAMOS UNA NUEVA TABLA EN BASE A AuditorEvaluationPlan DONDE SE REMOVERAN TODOS LOS REGISTROS DUPLICADOS PARA EL PK DE LA TABLA Audio
	SET @SQL_SELECT_1 += '
		WITH CTE AS (
			SELECT AEP.[Instance], 
					AEP.[IdEvaluationPlan], 
					AEP.[IdInteraction], 
					AEP.[IdAuditor], 
					AEP.[Score], 
					IEP.[AgentName],
					AEP.[LastModifiedDate],
					RN = ROW_NUMBER() OVER(PARTITION BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction] ORDER BY AEP.[LastModifiedDate] DESC)
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance] 
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction]
					AND IEP.[IdAgent] = AEP.[IdAgent]
			WHERE AEP.[Instance] = ''' + @Instance + ''' 				
				AND AEP.[IdAuditor] = ''SPEECH''
				AND AEP.[StatusDescription] NOT IN(''INVALID'') '

	
	IF (@IdCampaigns IS NOT NULL AND @IdCampaigns != '') SET @SQL_SELECT_1 += 'AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @IdCampaigns + ''','','')) ';
	IF (@IdAgents IS NOT NULL AND @IdAgents != '') SET @SQL_SELECT_1 += 'AND AEP.[IdAgent] IN (SELECT Value FROM [dbo].[split](''' + @IdAgents + ''','','')) ';	
	IF (@EvaluationPlans IS NOT NULL AND @EvaluationPlans != '') SET @SQL_SELECT_1 += 'AND AEP.[IdEvaluationPlan] IN (SELECT Value FROM [dbo].[split](''' + @EvaluationPlans + ''','','')) '
	IF (@InteractionTypes IS NOT NULL AND @InteractionTypes != '') SET @SQL_SELECT_1 += 'AND AEP.[InteractionType] IN (SELECT Value FROM [dbo].[split](''' + @InteractionTypes + ''','','')) ';
	IF (@InteractionResults IS NOT NULL AND @InteractionResults != '') 
		SET @SQL_SELECT_1 += 'AND (
								(CONCAT(AEP.[IdCampaign], ISNULL(REPLACE(AEP.[ManagementResult], ''/'', ''_''), ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(CONCAT(AEP.[IdCampaign], ''_'', ISNULL(AEP.[ManagementResult], ''_'')) IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
								OR
								(AEP.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @InteractionResults + ''','','')))
							)'

	SET @SQL_SELECT_1 += '
		),
		CLEANED_CTE AS (
			SELECT C.[Instance], 
					C.[IdEvaluationPlan], 
					C.[IdInteraction], 
					C.[IdAuditor], 
					C.[Score], 
					C.[AgentName],
					C.[LastModifiedDate]
			FROM [CTE] C
			WHERE C.[RN] = 1
		) '
	-- EL CTE SOLO PUEDE SER INVOCADO UNA VEZ POR ESO LO PONEMOS EN EL SELECT FINAL DONDE EL CONTADOR(RN) ES 1
	
	-- ARMAMOS EL SELECT PRINCIPAL PARA LA BUSQUEDA DE EVALUACIONES PENDIENTES DEL AUDITOR
	SET @SQL_SELECT_1 += '
		SELECT DISTINCT '
	SET @SQL_SELECT_1 += '
				AEP.[IdInteraction]															''id'', 
				AEP.[IdCampaign]															''descriptionCampaign'',
				AEP.[IdAgent]																''idAgent'',
				AEP.[IdAgent]																''descriptionAgent'',
				AEP.[InteractionDate]														''dateIni'',
				AEP.[InteractionDateEnd]													''dateFin'',
				AEP.[InteractionDuration]													''interactionTime'',
				AEP.[Completed]																''evaluated'',
				AEP.[InteractionType]														''interactionType'',
				AEP.[ManagementResult]														''dispositionCode'',
				AEP.[ContactAddress]																''address'',
				AEP.[InteractionOrigin]														''origin'',
				AEP.[IdEvaluationPlan]														''idEvaluationPlan'',
				EP.[ProcessId]																''processId'',
				EP.[Description]															''descriptionEvaluationPlan'',
				EP.[DateFin]																''dateFinEvaluationPlan'', 
				EP.[Modality]																''evaluationPlanModality'',
				EP.[Evaluation_Mode]														''evaluationPlanEvaluationMode'',
				A.[ID]																		''idAuditor'', 
				A.[Description]																''descriptionAuditor'',
				ISNULL(U.[FirstName] + '' '', '''') + ISNULL(U.[LastName], '''')			''auditorName'',						-- NOMBRE DEL AUDITOR
				C.[AgentName]																''agentName'',							-- NOMBRE DEL AGENTE
				C.[IdAuditor]																''lastEvaluationEvaluator'', 
				C.[Score]																	''lastEvaluationScore'',
				AEP.[Status]																''status'',
				ERE.[EfectivityStatus]														''statusDescription'',
				ERE.[EfectivityPlanId]														''efectivityPlanId''	'
	

	
	SET @SQL_FROM +='
	FROM [AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [EvaluationPlan] EP (NOLOCK) 
				ON (EP.[Instance] = EP.Instance
					AND EP.[ID] = AEP.IdEvaluationPlan) 
			INNER JOIN ( SELECT DISTINCT [VCC],[InteractionId],[AgentId],[EvaluationPlanId],[AuditorId],[EfectivityStatus],[EfectivityPlanId] FROM [EvaluationResultEfectivity] 
						 WHERE [EfectivityStatus] IN( ''' + 'CREATED'+''''+','+ ''''+ 'DRAFT'+''''+ ')' +						 

			')AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])
			INNER JOIN CLEANED_CTE C (NOLOCK) 
				ON C.[Instance] = AEP.[Instance] 
					AND C.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
					AND C.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN [dbo].[User] U (NOLOCK)
				ON U.[VCC] = AEP.[Instance]
					AND U.[ID] = ERE.[AuditorId]
			LEFT JOIN [Auditor] A (NOLOCK) 
				ON (A.[ID] = ERE.[AuditorId])
	'
	
		
	
	SET @FILTERS_FIXED_PART = '
	WHERE AEP.[Instance] = ''' + @Instance + ''' 
				--AND AEP.[Completed] = 0
				AND AEP.[StatusDescription] NOT IN(''INVALID'')
				AND EP.[Enabled] = 1 
				AND (
					(EP.[Evaluation_Mode] = ''X'' AND EP.[Status] = 7)
					OR
					(EP.[Evaluation_Mode] = ''A'')
				) 
	'

	IF (@EfectivityPlans IS NOT NULL AND @EfectivityPlans != '') SET  @FILTERS_FIXED_PART += 'AND  ERE.[EfectivityPlanId] IN (SELECT Value FROM [dbo].[split](''' + @EfectivityPlans + ''','','')) '
	

	-- AGREGAMOS EL FILTRO DE ESTADO
	IF @EvaluationStatus = 0
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 0 '
		SET @FILTERS_FIXED_PART_EFECTIVITY += '
				AND AEP.[Status] = 0 '
	END
	ELSE IF @EvaluationStatus = 1
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND AEP.[Status] = 1 '
        
		SET @FILTERS_FIXED_PART_EFECTIVITY += '
				AND AEP.[Status] = 1 '

	END

	-- HACEMOS EL FILTRADO SEGUN EL ROL DEL USUARIO
	IF @USER_ROLE = 'quality_auditor' OR @USER_ROLE = 'administrator'
	BEGIN
		SET @FILTERS_FIXED_PART += '
				AND	ERE.[AuditorId] = ''' + @UserId + ''' '      
		
	END
	--ELSE IF @USER_ROLE = 'administrator' OR @USER_ROLE = 'quality_admin'
	--BEGIN
	--	SET @FILTERS_FIXED_PART += ''		
	--END
	--ELSE 
	--BEGIN
	--	SET @FILTERS_FIXED_PART += '
	--			AND	ERE.[AuditorId] = ''' + @UserId + ''' '
		
	--END

	IF (@EvaluationDateTo IS NOT NULL AND @EvaluationDateTo != '') SET @FILTERS_OPTIONAL_PART += 'AND EP.[DateFin] <= ''' + @EvaluationDateTo + '''  ';
	IF(@ContactAddress IS NOT NULL AND @ContactAddress <>'')
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND AEP.ContactAddress LIKE ''%' + @ContactAddress + '%''
			'
	END	
	
	IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
       BEGIN 
            SET @FILTERS_OPTIONAL_PART = '';
	        SET @FILTERS_EXCLUDING_PART=' AND AEP.[IdInteraction] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) ';
       END

	
	
	SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART;

	--PRINT @SQL_SELECT_1
	EXEC (@SQL_SELECT_1)

 	SET NOCOUNT OFF
END
GO
PRINT N'Creating Procedure [dbo].[SaveEvaluationEfectivitySample]...';


GO
CREATE procedure [dbo].[SaveEvaluationEfectivitySample](
@VCC varchar(50),
@EfectivityPlanId varchar(50),
@EvaluationPlanId varchar(50),
@AuditorId varchar(50),
@SampleSize int
)
AS
BEGIN
	    
		IF (@SampleSize = -1)
		BEGIN
		UPDATE [dbo].[EvaluationResultEfectivity] 
			SET [AuditorId] = @AuditorId,
				[LastModifiedDate] = GETUTCDATE()
			WHERE 
			[VCC] = @VCC
			AND [EfectivityPlanId] = @EfectivityPlanId
			AND [EvaluationPlanId] = @EvaluationPlanId

			SELECT 1 AS 'result'
		END	

		ELSE
		BEGIN
			IF NOT EXISTS (SELECT 1 FROM [dbo].[EvaluationResultEfectivity] (NOLOCK) WHERE [VCC] = @VCC
			AND [EfectivityPlanId] = @EfectivityPlanId
			AND [EvaluationPlanId] = @EvaluationPlanId  )
			BEGIN 
				CREATE TABLE #RANDOM_INTERACTION(
				[IdInteraction] VARCHAR(250)
				)
				INSERT INTO #RANDOM_INTERACTION
				SELECT TOP (@SampleSize) [IEP].[IdInteraction]
										FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK) 
										WHERE IEP.[Instance] = @VCC
											  AND [IEP].[IdEvaluationPlan] = @EvaluationPlanId
											 -- AND IEP.[InteractionType] = @CURRENT_CHANNEL
										GROUP BY [IEP].[IdInteraction] 
										ORDER BY NEWID()

		

				INSERT INTO [dbo].[EvaluationResultEfectivity]						
				SELECT ER.[Instance],@EfectivityPlanId,ER.[IdEvaluationPlan],ER.[IdInteraction],ER.[IdAgent],ER.[IdAbilityEvaluationFormat],@AuditorId ,null,'CREATED',GETUTCDATE(),GETUTCDATE() 
				FROM [dbo].[EvaluationResult] ER (NOLOCK)
				INNER JOIN #RANDOM_INTERACTION RI ON 
				ER.IdInteraction = RI.IdInteraction 
				WHERE ER.Instance = @VCC AND
				ER.IdEvaluationPlan = @EvaluationPlanId

				SELECT 1 AS 'result'

			END
			ELSE
			BEGIN
			SELECT 0 AS 'result' FROM [dbo].[EvaluationResultEfectivity] WHERE [VCC] = @VCC
			AND [EfectivityPlanId] = @EfectivityPlanId
			AND [EvaluationPlanId] = @EvaluationPlanId
				
			END

			
		END

		
			
END
GO
PRINT N'Creating Procedure [dbo].[SaveEvaluationResultEfectivity]...';


GO

CREATE PROCEDURE [dbo].[SaveEvaluationResultEfectivity] (
	@VCC Varchar(50) = NULL,
	@EfectivityPlanId Varchar(50) = NULL,
	@EvaluationPlanId Varchar(50) = NULL,
	@InteractionId Varchar(250) = NULL,	
	@AbilityEvaluationFormatId Varchar(50) = NULL,	
	@Efectivity Varchar(50) = NULL,
	@EfectivityStatus Varchar(50) = NULL
)
AS
BEGIN
	SET NOCOUNT ON


	IF EXISTS(SELECT 1 FROM dbo.[EvaluationResultEfectivity](NOLOCK)
			  WHERE VCC = @VCC 
			  AND [EfectivityPlanId] = @EfectivityPlanId
			  AND [EvaluationPlanId] = @EvaluationPlanId
			  AND [InteractionId] = @InteractionId			  
			  AND [AbilityEvaluationFormatId] = @AbilityEvaluationFormatId
			  )
	BEGIN
	UPDATE [dbo].[EvaluationResultEfectivity] 
			SET [Efectivity] = @Efectivity,								   								
				[EfectivityStatus] = @EfectivityStatus,
				[LastModifiedDate] = GETUTCDATE()
				
			 WHERE [VCC] = @VCC 
			  AND [EfectivityPlanId] = @EfectivityPlanId
			  AND [EvaluationPlanId] = @EvaluationPlanId
			  AND [InteractionId] = @InteractionId			  
			  AND [AbilityEvaluationFormatId] = @AbilityEvaluationFormatId
    END 

    SELECT 1 AS 'result'

    SET NOCOUNT OFF
END
GO
PRINT N'Update complete.';


GO
