ALTER PROCEDURE [dbo].[SaveEvaluationBaseResult] (
	@VCC VARCHAR(50) = NULL,
	@EVALUATION_PLAN_ID VARCHAR(100) = NULL,
	@ABILITY_TYPE VARCHAR(50) = NULL
) AS
BEGIN
	-- ESTE SP INSERTA LOS RESULT BASE DE UN PLAN AUTOMATICO/MIXTO
	SET NOCOUNT ON

	-- SETTEAMOS EL TYPE ABILITY COMO AUTOMATIC PO DEFECTO
	IF @ABILITY_TYPE IS NULL SET @ABILITY_TYPE = 'AUTOMATIC'

	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART
	;WITH CTE AS (
		SELECT IEP.[Instance]									'vcc',
				IEP.[IdCampaign]								'IdCampaign',
				IEP.[IdInteraction]								'IdInteraction',
				IEP.[IdAgent]									'IdAgent',
				EP.[IdEvaluationFormat]							'IdEvaluationFormat',
				HEF.[MinQualificationAcceptable]				'MinQualificationAcceptable',
				HAEF.[IdGroup]									'IdGroup',
				HAEF.[IdSubGroup]								'IdSubGroup',
				HAEF.[IdAbility]								'IdAbility',
				HAEF.[Score]									'MaxAbilityScore',
				HS.[Value]										'AbilityInnerScore',
				EP.[ID]											'IdEvaluationPlan',
				HS.[Description]								'ScoreDescription',
				IEP.[IdCampaign]								'CampaignDescription',
				IEP.[IdAgent]									'AgentDescription',
				IEP.[InteractionDateStart]						'InteractionDateini',
				IEP.[InteractionDateEnd]						'InteractionDatefin',
				IEP.[ContactId]									'InteractionAddress',
				HAEF.[Order]									'AbilityOrder',
				IEP.[InteractionType]							'InteractionType',
				HAEF.[ID]										'IdAbilityEvaluationFormat',
				HAEF.[Conditional]								'Conditional',
				RN = ROW_NUMBER() OVER(PARTITION BY IEP.[IdCampaign],
													IEP.[IdInteraction],
													IEP.[IdAgent],
													EP.[IdEvaluationFormat],
													HEF.[MinQualificationAcceptable],
													HAEF.[IdGroup],
													HAEF.[IdSubGroup],
													HAEF.[IdAbility],
													HS.[Value],
													HS.[Description],
													IEP.[IdCampaign],
													IEP.[IdAgent],
													IEP.[InteractionDateStart],
													IEP.[InteractionDateEnd],
													HAEF.[Order],
													IEP.[InteractionType],
													HAEF.[ID],
													HAEF.[Conditional]
										ORDER BY IEP.[InteractionSection] ASC, IEP.[InteractionPart] ASC)
			FROM [dbo].[EvaluationPlan] EP (NOLOCK)
			INNER JOIN [dbo].[HistoricEvaluationFormat] HEF (NOLOCK)
				ON HEF.[VCC] = EP.[Instance]
					AND HEF.[EvaluationPlanId] = EP.[ID]
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = EP.[Instance]
					AND IEP.[IdEvaluationPlan] = EP.[ID]
			INNER JOIN [dbo].[HistoricAbilityEvaluationFormat] HAEF (NOLOCK)
				ON HAEF.[VCC] = EP.[Instance]
					AND HAEF.[EvaluationPlanId] = EP.[ID]
			INNER JOIN [dbo].[HistoricAbility] HA (NOLOCK)
				ON HA.[VCC] = EP.[Instance]
					AND HA.[EvaluationPlanId] = EP.[ID]
			LEFT JOIN [dbo].[Intent] I (NOLOCK)
				ON I.[VCC] = EP.[Instance]
					AND I.[IntentId] = HA.[QueryName]
			INNER JOIN [dbo].[HistoricScore] HS (NOLOCK)
				ON HS.[VCC] = IEP.[Instance]
					AND HS.[EvaluationPlanId] = EP.[ID]
					AND HS.[IdAbility] = HA.[ID]
					AND HS.[Value] = IIF(HA.[IsNegative] = 1, 100, 0)
			/*
			LEFT JOIN EvaluationFormat EF (NOLOCK)
				ON EF.[Instance] = EP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN InteractionEvaluationPlan IEP (NOLOCK)
				ON IEP.[Instance] = EP.[Instance]
					AND IEP.[IdEvaluationPlan] = EP.[ID]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK)
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EF.[ID]
			LEFT JOIN Ability A (NOLOCK)
				ON A.[Instance] = EP.[Instance]
					AND A.[ID] = AEF.[IdAbility]
			LEFT JOIN Intent I (NOLOCK)
				ON I.[VCC] = EP.[Instance]
					AND I.[IntentId] = A.[QueryName]
			LEFT JOIN [dbo].[Score] S (NOLOCK)
				ON S.[Instance] = IEP.[Instance]
					AND S.[IdAbility] = A.[ID]
					AND S.[Value] = IIF(A.[IsNegative] = 1, 100, 0)
			*/
			LEFT JOIN [dbo].[EvaluationResult] ER (NOLOCK)
				ON ER.[Instance] = IEP.[Instance]
					AND ER.[IdEvaluationPlan] = IEP.[IdEvaluationPlan]
					AND ER.[IdAgent] = IEP.[IdAgent]
					AND ER.[IdAbilityEvaluationFormat] = HAEF.[ID]
			LEFT JOIN [dbo].[ProcessAudio] PA (NOLOCK)
			    ON PA.[ProcessId] = EP.[ProcessId]
			LEFT JOIN [dbo].[Audio] AU (NOLOCK)
			    ON PA.[AudioId] = AU.[ID]
			    AND IEP.[IdInteraction] = AU.[ID]
			WHERE IEP.[IdInteraction] IS NOT NULL
				AND (
					-- (@ABILITY_TYPE = 'AUTOMATIC' AND I.[VCC] IS NOT NULL)
					(@ABILITY_TYPE = 'AUTOMATIC' AND HA.[Type] = 'MANUAL_AUTOMATIC')
					OR
					-- (@ABILITY_TYPE = 'MANUAL' AND I.[VCC] IS NULL)
					(@ABILITY_TYPE = 'MANUAL' AND HA.[Type] = 'MANUAL')
				)
				AND ER.[Instance] IS NULL
				AND EP.[ID] = @EVALUATION_PLAN_ID
				AND EP.[Instance] = @VCC
			    -- SI TIENE AUDIO DEBE ESTAR TRANSCRITO
			    AND (
					(
						AU.[ID] IS NOT NULL 
						AND 
						AU.[IsTranscribed] = 1
					)
					OR 
					IEP.[InteractionType] <> 'CALL'
				) 

	)

	-- INSERTAMOS SOLO LAS PRIMERAS OCURRENCIAS PARA CADA INTERACCION
	INSERT INTO [dbo].[EvaluationResult] (
		[Instance], [IdCampaign], [IdInteraction],
		[IdAgent], [IdEvaluationFormat], [MinQualificationAcceptable],
		[IdGroup], [IdSubGroup], [IdAbility],
		[Qualification], [OwnScore], [AbilityInnerScore],
		[IdEvaluator], [EvaluationDate], [MaxAbilityScore],
		[IdEvaluationPlan], [CreatedDate], [CreatedByUserId],
		[LastModifiedDate], [LastModifiedByUserId], [TimeStamp],
		[Comment], [NotApplies], [ScoreDescription],
		[CampaignDescription], [AgentDescription], [InteractionDateini],
		[InteractionDatefin], [InteractionAddress], [AbilityOrder],
		[InteractionType], [IdAbilityEvaluationFormat],  [IdAuditor],
		[Conditional]
	)
		SELECT C.[vcc], C.[IdCampaign], C.[IdInteraction],
				C.[IdAgent], C.[IdEvaluationFormat], C.[MinQualificationAcceptable],
				C.[IdGroup], C.[IdSubGroup], C.[IdAbility],
				(C.[MaxAbilityScore] * C.[AbilityInnerScore] / 100), (C.[MaxAbilityScore] * C.[AbilityInnerScore] / 100), C.[AbilityInnerScore],
				'SPEECH', GETUTCDATE(), C.[MaxAbilityScore],
				C.[IdEvaluationPlan], GETUTCDATE(), 'SPEECH',
				--'100', C.[IdEvaluationPlan], GETUTCDATE(),
				GETUTCDATE(), 'SPEECH', GETUTCDATE(),
				NULL, '0', C.[ScoreDescription],
				C.[CampaignDescription], C.[AgentDescription], C.[InteractionDateini],
				C.[InteractionDatefin], C.[InteractionAddress], C.[AbilityOrder],
				C.[InteractionType], C.[IdAbilityEvaluationFormat], 'SPEECH',
				C.[Conditional]
			FROM CTE C
			WHERE C.RN = 1

	SET NOCOUNT OFF
END
GO

ALTER PROCEDURE [dbo].[BulkAbilityCognitive]
AS
BEGIN
	SET NOCOUNT ON
	--select * from Dummy 
	--truncate table Dummy
	/*
	CREATE TABLE TMP_EVALUATIONPLANABILITY(
		VCC VARCHAR(50),
		ProcessId VARCHAR(50),
		EvaluationPlanId  VARCHAR(200),
		ID VARCHAR(250),
		Section  VARCHAR(50),
		Part VARCHAR(50),
		QueryId VARCHAR(50),
		TranscriptionId VARCHAR(200),
		NluId VARCHAR(50),
		IntentName VARCHAR(50),
		EndDate VARCHAR(50),
		Channel VARCHAR(50),
		Campaign VARCHAR(50)
	)
	*/

	/*insert into DummyEvaluationPlanAbility ([VCC]) values ('BULK')
	insert into TMP_EVALUATIONPLANABILITY ([VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign])  
	SELECT [VCC]
		  ,[ProcessId]
		  ,[EvaluationPlanId]
		  ,[ID]
		  ,[Section]
		  ,[Part]
		  ,[QueryId]
		  ,[TranscriptionId]
		  ,[NluId]
		  ,[IntentName]
		  ,[EndDate]
		  ,[Channel]
		  ,[Campaign]
	  FROM [dbo].[#AbilityCognitiveTemp]
	*/  

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT ACTMP.[VCC],
							ACTMP.[EvaluationPlanId] 'EVALUATION_PLAN_ID'
						FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
						WHERE ACTMP.[VCC] IS NOT NULL 
							AND ACTMP.[EvaluationPlanId] IS NOT NULL

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'
			
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	
	/* Script para actualizar a puntaje 100 la calificacion de cada habilidad retornada por luis */
	/*
	SELECT EP.[Description],
			ACTMP.[ID],
			I.[IntentId],
			I.[Name],
			A.[Title],
			AEP.Completed,
			ER.[Qualification],
			I.[AppId]
			*/

	UPDATE ER
		SET ER.[Qualification] = (AEF.[Score] * S.[Value]) / 100,
			ER.[OwnScore] = (AEF.[Score] * S.[Value]) / 100,
			ER.[ScoreDescription] = S.[Description],
			ER.[AbilityInnerScore] = S.[Value]
		FROM [#AbilityCognitiveTemp] ACTMP 
		INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
			ON EP.[ID] = ACTMP.[EvaluationPlanId]
		INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
			ON AEF.[Instance] = EP.[Instance]
				AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND AEF.[IdAbility] = ACTMP.[AbilityId]
		INNER JOIN EvaluationResult ER (NOLOCK)
			ON ER.[Instance] = EP.[Instance] 
				AND ER.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				AND ER.[IdInteraction] = ACTMP.[ID]
		INNER JOIN [dbo].[Ability] A (NOLOCK) 
	       ON A.[Instance] = ER.[Instance] 
	            AND A.[ID] = ER.[IdAbility]
		INNER JOIN [dbo].[Score] S (NOLOCK)
			ON S.[IdAbility] = ACTMP.[AbilityId]
				AND S.[Value] = IIF(A.[IsNegative] = 1, 0, 100)
		WHERE AEF.[IdAbility] = ER.[IdAbility]
			AND ER.[IdAuditor] = 'SPEECH'
	
	/* Script para actualizar la tabla AuditorEvaluationPlan a Completed y Suma de Scores de la evaluacion */
	UPDATE AEP
		SET --AEP.[Completed] = '1',
			AEP.[Completed] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN '0' ELSE '1' END,
			AEP.[StatusDescription] = CASE WHEN AEPR.[Evaluation_Mode] = 'X' AND AEPR.[MinAutomaticQualification] <= AEPR.[SCORE] THEN 'NEW' ELSE 'COMPLETED' END,
			AEP.[Score] = AEPR.[SCORE],
			AEP.[AutomaticScore] = AEPR.[SCORE],
			-- AEP.[ManualScore] = AEPR.[SCORE], -- UNA EVALUACION AUTOMATICA DEBE TENER 0 DE MANUALSCORE
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN (
			SELECT AEP.[Instance],
				AEP.[IdEvaluationPlan],
				AEP.[IdInteraction],
				EP.[Evaluation_Mode],
				EF.[MinAutomaticQualification],
				SUM(ER.[Qualification]) AS SCORE
			FROM AuditorEvaluationPlan AEP (NOLOCK)
			LEFT JOIN EvaluationPlan EP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan] 
			LEFT JOIN [dbo].[EvaluationFormat] EF (NOLOCK)
				ON EF.[Instance] = AEP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN EvaluationResult ER (NOLOCK)
				ON ER.[Instance] = AEP.[Instance]
					AND ER.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND ER.[IdInteraction] = AEP.[IdInteraction]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK) 
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			LEFT JOIN (SELECT DISTINCT ACTMP.[VCC],
									ACTMP.[EvaluationPlanId]
								FROM [#AbilityCognitiveTemp] ACTMP (NOLOCK)
								WHERE ACTMP.[VCC] IS NOT NULL 
									AND ACTMP.[EvaluationPlanId] IS NOT NULL) TMP 
				ON TMP.[VCC] = AEP.[Instance]
					AND TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
			WHERE TMP.[EvaluationPlanId] = AEP.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = 'SPEECH'
			GROUP BY AEP.[Instance], AEP.[IdEvaluationPlan], AEP.[IdInteraction], EP.[Evaluation_Mode], EF.[MinAutomaticQualification]
		) AEPR 
		ON AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
		WHERE AEPR.[Instance] = AEP.[Instance]
			AND AEPR.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
			AND AEPR.[IdInteraction] = AEP.[IdInteraction]
	
	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp]) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor],
				SUM(ER.[Qualification])															'TOTAL_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
				--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
				SUM(ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
				))																				'PENALIZED_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_MANUAL_SCORE'
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[IdInteraction], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP2
				ON FP2.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
					AND ER.[IdInteraction] = FP2.[IdInteraction]
					/*
					AND CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
					AND FP2.[Penalized] = 1
					*/
			INNER JOIN dbo.[HistoricAbility] HA (NOLOCK)
				ON HA.[VCC] = ER.[Instance]
					AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HA.[ID] = ER.[IdAbility]
			--WHERE ER.[Instance] = 'multisalud'
			WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
				-- AND 
				ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM [#AbilityCognitiveTemp])
				--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
			AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
				AND FS.[IdAuditor] = AEP.[IdAuditor]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
     --insert into test(origin,content) values('BulkAbilityCognitive',(select *  from [dbo].[#AbilityCognitiveTemp] FOR JSON AUTO))
	DROP TABLE [dbo].[#AbilityCognitiveTemp];
	
	SET NOCOUNT OFF
END
GO

ALTER PROCEDURE [dbo].[BulkEvaluationPlanAbility]
AS
BEGIN
	SET NOCOUNT ON
	-- ESTE PROCEDURE RECIBE COMO RESULTADO LAS INTERACCIONES QUE COINCIDEN CON UN QUERY EN UN PLAN DE EVALUACION
	
	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR LOS PLANES Y SU CORRESPONDIENTE VCC
	DECLARE MY_CURSOR CURSOR 
	LOCAL STATIC READ_ONLY FORWARD_ONLY -- SCROLL 
		FOR 
		-- CONSULTAMOS LOS ID DE PLANES EN LA TABLA TEMPORAL
		SELECT DISTINCT
				EPATMP.[VCC]						'VCC', 
				EPATMP.[EvaluationPlanId]			'EVALUATION_PLAN_ID'
			FROM [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)

	-- DECLARARAMOS VARIABLES PARA INDICAR EL PLAN Y VCC
	DECLARE @CURRENT_VCC VARCHAR(50) = ''
	DECLARE @CURRENT_EVALUATION_PLAN_ID VARCHAR(100) = ''

	-- ABRIMOS Y RECORREMOS EL ARRAY DE CANALES
	OPEN MY_CURSOR
	FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	WHILE @@FETCH_STATUS = 0
	BEGIN 
		-- EJECUTAMOS EL SP QUE INSERTA LOS RESULT BASE DE LOS PLANES QUE AUN NO LOS TIENEN
		EXEC [dbo].[SaveEvaluationBaseResult] @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID, 'AUTOMATIC'

		-- INSERTAMOS LOS RESULTADOS DE LAS INTERACCIONES DE AUDIO QUE MATCHEARON CON LA QUERY
		INSERT INTO [dbo].[InteractionQueryResult] (
			[VCC],
			[InteractionId],
			[Section],
			[Part],
			[InteractionType],
			[TranscriptionId],
			[BatchType],
			[BatchTypeId],
			[BatchTypeName],
			[AnalysisType],
			[QueryId],
			[QueryName],
			[QueryValue],
			[QueryData],
			[Matches],
			[Details],
			[CreatedDate],
			[TimeStamp]
		)
			SELECT @CURRENT_VCC,
					PA.[AudioId],
					PA.[Section],
					PA.[Part],
					'CALL', --EPATMP.[Channel],
					CONCAT(PA.[AudioId], '_', ISNULL(PA.[Section], '0'), '_', ISNULL(PA.[Part], '0')),
					'EVALUATION_PLAN',
					@CURRENT_EVALUATION_PLAN_ID,
					EP.[Description],
					'SEMANTIC',
					GQ.[Name],
					GQ.[Name],
					GQ.[Query],
					GQ.[RawData],
					EPATMP.[Matches],
					EPATMP.[MatchesDetail],
					GETUTCDATE(),
					GETUTCDATE()
				FROM [#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = EPATMP.[VCC]
						AND EP.[ID] = EPATMP.[EvaluationPlanId]
				INNER JOIN [dbo].[ProcessAudio] PA (NOLOCK)
					ON PA.[VCC] = EPATMP.[VCC]
						AND PA.[ProcessId] = EPATMP.[ProcessId]
						AND PA.[AudioId] = EPATMP.[AudioId]
						AND PA.[Section] = EPATMP.[Section]
						AND PA.[Part] = EPATMP.[Part]
				INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
					ON AEF.[Instance] = EPATMP.[VCC]
						AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				/*
				INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
					ON AQ.[VCC] = EPATMP.[VCC]
						AND AQ.[AbilityId] = AEF.[IdAbility] 
						AND AQ.[QueryId] = EPATMP.[QueryId]
				*/
				INNER JOIN [GenericQuery] GQ (NOLOCK)
					ON GQ.[VCC] = EPATMP.[VCC]
						AND GQ.[Name] = EPATMP.[QueryId]
				WHERE EPATMP.[VCC] = @CURRENT_VCC
					AND EPATMP.[EvaluationPlanId] = @CURRENT_EVALUATION_PLAN_ID

		-- INSERTAMOS LOS RESULTADOS DE LAS INTERACCIONES DE TEXTO QUE MATCHEARON CON LA QUERY
		INSERT INTO [dbo].[InteractionQueryResult] (
			[VCC],
			[InteractionId],
			[Section],
			[Part],
			[InteractionType],
			[TranscriptionId],
			[BatchType],
			[BatchTypeId],
			[BatchTypeName],
			[AnalysisType],
			[QueryId],
			[QueryName],
			[QueryValue],
			[QueryData],
			[Matches],
			[Details],
			[CreatedDate],
			[TimeStamp]
		)
			SELECT @CURRENT_VCC,
					PAI.[InteractionId],
					NULL,
					NULL,
					EPATMP.[Channel],
					EPATMP.[AudioId],
					'EVALUATION_PLAN',
					@CURRENT_EVALUATION_PLAN_ID,
					EP.[Description],
					'SEMANTIC',
					GQ.[Name],
					GQ.[Name],
					GQ.[Query],
					GQ.[RawData],
					EPATMP.[Matches],
					EPATMP.[MatchesDetail],
					GETUTCDATE(),
					GETUTCDATE()
				FROM [#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
				INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
					ON EP.[Instance] = EPATMP.[VCC]
						AND EP.[ID] = EPATMP.[EvaluationPlanId]
				INNER JOIN [dbo].[ProcessAsyncInteraction] PAI (NOLOCK)
					ON PAI.[VCC] = EPATMP.[VCC]
						AND PAI.[ProcessId] = EPATMP.[ProcessId]
						AND PAI.[InteractionType] = EPATMP.[Channel]
						AND PAI.[FormattedEndDate] = EPATMP.[EndDate]
						AND PAI.[Campaign] = EPATMP.[Campaign]
						AND CONCAT(PAI.[InteractionType], '_', PAI.[Campaign], '_', PAI.[FormattedEndDate], '_', REPLACE(PAI.[InteractionId], ':', '_')) = EPATMP.[AudioId]
				INNER JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
					ON AEF.[Instance] = EPATMP.[VCC]
						AND AEF.[IdEvaluationFormat] = EP.[IdEvaluationFormat]
				/*
				INNER JOIN [dbo].[AbilityQuery] AQ (NOLOCK)
					ON AQ.[VCC] = EPATMP.[VCC]
						AND AQ.[AbilityId] = AEF.[IdAbility] 
						AND AQ.[QueryId] = EPATMP.[QueryId]
				*/
				INNER JOIN [GenericQuery] GQ (NOLOCK)
					ON GQ.[VCC] = EPATMP.[VCC]
						AND GQ.[Name] = EPATMP.[QueryId]
				WHERE EPATMP.[VCC] = @CURRENT_VCC
					AND EPATMP.[EvaluationPlanId] = @CURRENT_EVALUATION_PLAN_ID
		
		FETCH NEXT FROM MY_CURSOR INTO @CURRENT_VCC, @CURRENT_EVALUATION_PLAN_ID
	END
	CLOSE MY_CURSOR
	DEALLOCATE MY_CURSOR
	-- FIN MEDIDA PARA PLANES FINALIZADOS QUE NO TIENE RESULTS REGISTRADOS

	
	
	
	--ACTUALIZAR LOS SCORES DE LAS HABILIDADES RETORNADAS EN LA TABLA TEMPORAL
	UPDATE ER 
	SET ER.[Qualification] = (S.[Value] * AEF.[Score] / 100), 
		ER.[OwnScore] = (AEF.[Score] * S.[Value]) / 100,
		ER.[ScoreDescription] = S.[Description],
		ER.[AbilityInnerScore] = S.[Value]
	FROM [dbo].[EvaluationResult] ER (NOLOCK)
	INNER JOIN [dbo].[#EvaluationPlanAbilityTemp] EPATMP (NOLOCK)
	--INNER JOIN [dbo].[DummyEvaluationPlanAbility] EPATMP (NOLOCK)
		ON ER.[Instance] = EPATMP.[VCC]
		AND ER.[IdEvaluationPlan] = EPATMP.[EvaluationPlanId]
		AND ER.[IdInteraction] = EPATMP.[AudioId] 
	LEFT JOIN [dbo].[AbilityEvaluationFormat] AEF (NOLOCK)
		ON AEF.[Instance] = ER.[Instance] 
		AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
		AND AEF.[IdAbility] = ER.[IdAbility]
	INNER JOIN [dbo].[Ability] A (NOLOCK) 
		ON A.[Instance] = ER.[Instance] 
		AND A.[ID] = ER.[IdAbility]
	INNER JOIN [dbo].[AbilityQuery] AB (NOLOCK)
		ON AB.[VCC] = ER.[Instance] 
			AND AB.[AbilityId] = AEF.[IdAbility]
			AND AB.[QueryId] = EPATMP.[QueryId]
	LEFT JOIN [dbo].[Score] S (NOLOCK) 
		ON S.[Instance] = ER.[Instance] 
		AND S.[IdAbility] = ER.[IdAbility]
		AND S.[Value] =  IIF(A.[IsNegative] = 1, 0, 100);

	WITH 
	-- DECLARAMOS UNA CTE PARA DEPOSITAR LOS RESULTADOS DE LA SUMA DE HABILIDADES PARA LA EVALUACION
	CteEvaluationScoreResult AS (
		-- ESTE BLOQUE ACTUALIZA LAS NOTAS DE EVALUACIONES AUTOMATICAS SEGUN LOS PLANES CONTENIDOS EN LA TEMPORAL
		SELECT ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction], SUM(ER.[Qualification]) TOTAL
			FROM EvaluationResult ER 
			INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) EPATMP 
			--INNER JOIN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) EPATMP 
				ON EPATMP.[EvaluationPlanId] = ER.[IdEvaluationPlan] 
			LEFT JOIN AbilityEvaluationFormat AEF 
				ON AEF.[Instance] = ER.[Instance]
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
					AND AEF.[ID] = ER.[IdAbilityEvaluationFormat]
			WHERE ER.[IdAuditor] = 'SPEECH'
			GROUP BY ER.[Instance], ER.[IdEvaluationPlan], ER.[IdEvaluator], ER.[IdInteraction]
	)
	
	-- SE ACTUALIZA LAS EVALUACIONES QUE COINCIDEN CON LOS RESULTADOS
	UPDATE AEP 
		SET AEP.[Score] = ESR.[TOTAL],
			AEP.[AutomaticScore] =  ESR.[TOTAL],
			AEP.[ManualScore] = 0,
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		INNER JOIN CteEvaluationScoreResult ESR 
			ON AEP.[Instance] = ESR.[Instance]
				AND AEP.[IdEvaluationPlan] = ESR.[IdEvaluationPlan]
				AND AEP.[IdAuditor] = ESR.[IdEvaluator]
				AND AEP.[IdInteraction] = ESR.[IdInteraction]

	;
	/****************************************************************************************/
	/*INICIO SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/****************************************************************************************/
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA DETERMINAR LAS INTERACCIONES QUE TIENEN HABILIDAD(ES) PENALIZADA(S) POR NOTA CERO
	--  ORDENANDO POR PRIORIDAD (INTERACCION 1, GRUPO 2 Y SUBGRUPO 3)
	WITH CTEFP AS (
		SELECT DISTINCT 
				ER.[Instance],
				ER.[IdInteraction],
				ER.[IdEvaluationPlan],
				ER.[IdEvaluationFormat],
				ER.[IdAbility],
				CASE WHEN ER.[Qualification] = 0 AND AEF.[Penalizes] <> 'NO' THEN 1 ELSE 0 END 'Penalized',
				AEF.[Penalizes],
				CASE AEF.[Penalizes]
					WHEN 'INT' THEN ER.[IdInteraction] 
					WHEN 'GRP' THEN ER.[IdGroup] 
					WHEN 'SGR' THEN ER.[IdSubGroup] 
				END 'PenalizedOn',
				RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdInteraction], CASE WHEN ER.[Qualification] = 0 THEN 1 ELSE 0 END 
					ORDER BY CASE AEF.[Penalizes]
					WHEN 'INT' THEN 1 
					WHEN 'GRP' THEN 2 
					WHEN 'SGR' THEN 3 
				END)
			FROM [EvaluationResult] ER (NOLOCK) 
			LEFT JOIN [AbilityEvaluationFormat] AEF (NOLOCK) 
				ON AEF.[Instance] = ER.[Instance] 
					AND AEF.[IdEvaluationFormat] = ER.[IdEvaluationFormat]
					AND AEF.[IdAbility] = ER.[IdAbility]
			WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp) 
			--WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility) 
				AND ER.[Qualification] = 0 
				AND AEF.[Penalizes] <> 'NO'
			-- WHERE ER.[IdEvaluationPlan] IN (SELECT DISTINCT EPA.[EvaluationPlanId] FROM [DummyEvaluationPlanAbility] EPA (NOLOCK) WHERE EPA.[EvaluationPlanId] IS NOT NULL)
	),
	--SELECT * FROM CTEFP

	-- ALMACENAMOS EL RESULTADO AGRUPADO DE LAS EVALUACIONES EN UNA TABLA VARIABLE PARA HACER UN CRUCE DIRECTO CON
	--  LA TABLA AuditorEvaluationPlan
	CTEFS AS (
		SELECT ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor],
				SUM(ER.[Qualification])															'TOTAL_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC', ER.[Qualification], 0))					'TOTAL_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL', ER.[Qualification], 0))							'TOTAL_MANUAL_SCORE',
				--SUM(ER.[Qualification] * CASE WHEN FP2.[Penalized] IS NULL THEN 1 ELSE 0 END) 'PENALIZED_SCORE',
				SUM(ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1) THEN 0 ELSE 1 END
				))																				'PENALIZED_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL_AUTOMATIC',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_AUTOMATIC_SCORE',
				SUM(IIF(HA.[Type] = 'MANUAL',
					ER.[Qualification] * (
					CASE WHEN (
						CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
						AND FP2.[Penalized] = 1
					) THEN 0 ELSE 1 END),
					0) 
				)																				'PENALIZED_MANUAL_SCORE'
			FROM EvaluationResult ER (NOLOCK) 
			LEFT JOIN (
				-- HACEMOS UN CRUCE CON LA TABLA VARIABLE Y TOMAMOS SOLO UNA DE LAS PENALIZACIONES POR INTERACCION, EMPEZANDO 
				--  POR LA MAS PRIORITARIA (FP.[RN])
				SELECT DISTINCT FP.[Instance],
								FP.[IdEvaluationPlan], 
								FP.[IdInteraction], 
								FP.[Penalized],
								FP.[Penalizes], 
								FP.[PenalizedOn]
					FROM CTEFP FP (NOLOCK)
					WHERE FP.[Penalizes] <> 'NO'
						AND FP.[RN] = 1
			) FP2
				ON FP2.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = FP2.[IdEvaluationPlan]
					AND ER.[IdInteraction] = FP2.[IdInteraction]
					/*
					AND CASE FP2.[Penalizes]
							WHEN 'INT' THEN ER.[IdInteraction] 
							WHEN 'GRP' THEN ER.[IdGroup] 
							WHEN 'SGR' THEN ER.[IdSubGroup] 
						END = FP2.[PenalizedOn]
					AND FP2.[Penalized] = 1
					*/
			INNER JOIN dbo.[HistoricAbility] HA (NOLOCK)
				ON HA.[VCC] = ER.[Instance]
					AND HA.[EvaluationPlanId] = ER.[IdEvaluationPlan]
					AND HA.[ID] = ER.[IdAbility]
			--WHERE ER.[Instance] = 'multisalud'
			WHERE -- ER.[Instance] = FP2.[Instance] -- ESTA LINEA CAUSA QUE NO SE ACTUALICEN LOS SCORES LAS EVALUACIONES QUE NO PENALIZAN
				-- AND 
				ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM #EvaluationPlanAbilityTemp)
				--AND ER.[IdEvaluationPlan] IN (SELECT DISTINCT EvaluationPlanId FROM DummyEvaluationPlanAbility)
			GROUP BY ER.[Instance],
				ER.[IdEvaluationPlan],
				ER.[IdInteraction],
				ER.[IdAuditor]
	)
	--SELECT * FROM CTEFS

	-- ACTUALIZAMOS LOS REGISTROS DE EVALUACION CON LA NOTA PENALIZADA OBTENIDA EN LOS PASOS ANTERIORES
	UPDATE AEP 
		SET AEP.[Score] = FS.[PENALIZED_SCORE],
			AEP.[AutomaticScore] = FS.[PENALIZED_AUTOMATIC_SCORE],
			AEP.[ManualScore] = FS.[PENALIZED_MANUAL_SCORE],
			AEP.[LastModifiedDate] = GETUTCDATE(),
			AEP.[TimeStamp] = GETUTCDATE()
		FROM AuditorEvaluationPlan AEP (NOLOCK)
		LEFT JOIN CTEFS FS (NOLOCK) 
			ON FS.[Instance] = AEP.[Instance] 
				AND FS.[IdEvaluationPlan] = AEP.[IdEvaluationPlan] 
				AND FS.[IdInteraction] = AEP.[IdInteraction]
				AND FS.[IdAuditor] = AEP.[IdAuditor]
		WHERE FS.[Instance] IS NOT NULL
		
	/*************************************************************************************/
	/*FIN SECCION PARA ACTUALIZAR LA CALIFICACION TOTAL DE LA EVALUACION C/S PENALIZACION*/
	/*************************************************************************************/
	--insert into test(origin,content) values('BulkAbilityCognitive',(select *  from [dbo].[#AbilityCognitiveTemp] FOR JSON AUTO))

	-- ELIMINAMOS LA TABLA TEMPORAL
	DROP TABLE [dbo].[#EvaluationPlanAbilityTemp]
	
	SET NOCOUNT OFF
END
GO
