PRINT N'Modificando Procedimiento [dbo].[CreateVcc]...';


GO
ALTER PROCEDURE [dbo].[CreateVcc] (
	@VCC Varchar(50) = NULL, 
	@ID Varchar(50) = NULL,
	@Description Varchar(50) = NULL,
	@Type VARCHAR(50) = NULL,
	@TranscriptionDefaultLanguage VARCHAR(25) = NULL,
	@CognitiveEngine VARCHAR(25) = NULL,
	@Country Varchar(50) = NULL,
	@Language Varchar(50) = NULL,
	@TimeZone Varchar(50) = NULL,
	@CreatedDate Datetime = NULL,
	@CreatedByUserId Varchar(50) = NULL,
	@LastModifiedDate Datetime = NULL,
	@LastModifiedByUserId   VARCHAR(50) = NULL,
	@DeleteDataDays         INT = 360
	)
AS
BEGIN
	SET NOCOUNT ON
	BEGIN TRY
    BEGIN TRANSACTION


	INSERT INTO [dbo].[VCC] (
			[VCC], 
			[ID], 
			[Description], 
			[Type], 
			[Country], 
			[TranscriptionDefaultLanguage], 
			[CognitiveEngine], 
			[Language],
			[TimeZone], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[DeleteDataDays], 
			[TimeStamp]
			)
	VALUES (
			@VCC, 
			@ID, 
			@Description, 
			@Type, 
			@Country, 
			@TranscriptionDefaultLanguage, 
			@CognitiveEngine, 
			@Language, 
			@TimeZone, 
			@CreatedDate,  
			@CreatedByUserId, 
			@LastModifiedDate, 
			@LastModifiedByUserId, 
			@DeleteDataDays,
			GETUTCDATE()
		)
	
	DECLARE @VCC_SYSTEM       VARCHAR(50) = 'system'

    --INSERTAR ROLES
	
	DECLARE @ROLES TABLE(
    [ID]            VARCHAR(50),
    [Description]   VARCHAR(50),
	[CreatedDate]   DATETIME,
    [CreatedByUserId] VARCHAR(50),
    [LastModifiedDate] DATETIME,
    [LastModifiedByUserId] VARCHAR(50),
	[SystemRole]    BIT,
    [Type]                 VARCHAR(50)
	)
	INSERT INTO @ROLES EXEC [dbo].[GetRoles] @VCC_SYSTEM,'name',''

	IF(EXISTS(SELECT [ID] FROM @ROLES))
	BEGIN
			INSERT INTO [dbo].[Role] (
					[VCC],
					[ID], 
					[Description],
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate],
					[LastModifiedByUserId],
					[SystemRole],
					[Type],
					[TimeStamp]
					)
			SELECT @VCC,
				   [ID],
				   [Description],
				   GETUTCDATE(), 
				   [CreatedByUserId],
				   GETUTCDATE(),
				   [LastModifiedByUserId],
				   [SystemRole],
				   [Type],
				   GETUTCDATE()
			FROM @ROLES
     END
	 ELSE
	 BEGIN
	       RAISERROR('SERVER_ERROR_ROLES_NOT_FOUND', 16, 16)
	 END

	--INSERTAR PERMISOS PARA LOS ROLES

	DECLARE @CountLicense INT = 0
	DECLARE @License      VARCHAR(50)
	
	DECLARE @ROLE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)
	DECLARE @ROUTE_PERMISSIONS TABLE(
	 [ID]      VARCHAR(50),
	 [Route]   VARCHAR(250),
	 [Level]   VARCHAR(50),
	 [GroupId] VARCHAR(200)
	)

	SET @CountLicense = (SELECT COUNT(*) FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	
	IF(@CountLicense>1)
	BEGIN
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,''
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM
	END

	IF(@CountLicense=1)
	BEGIN
	    SET @License = (SELECT Product FROM [dbo].[VCCLicense] (NOLOCK) WHERE [VCC] = @VCC AND [Status] = 1)
	    INSERT INTO @ROLE_PERMISSIONS EXEC [dbo].[GetRolePermission] @VCC_SYSTEM,'', @License
		INSERT INTO @ROUTE_PERMISSIONS EXEC [dbo].[GetRoleRoutePermission] @VCC_SYSTEM,'', @License
	END
	
	INSERT INTO [dbo].[RolePermission] (
			    [VCC], 
				[RoleId], 
				[GroupId],
			    [TimeStamp]
			    ) 
				SELECT 
				@VCC,
				[ID],
				[GroupId],
			    GETUTCDATE()
				FROM @ROLE_PERMISSIONS

	INSERT INTO [dbo].[RoutePermission] (
			[VCC], 
			[ID], 
			[GroupId],
			[Route], 
			[Level], 
			[TimeStamp]
			)
			SELECT 
			@VCC,
			[ID],
			[GroupId],
			[Route],
			[Level],
			GETUTCDATE()
			FROM @ROUTE_PERMISSIONS


    --INSERTAR GRUPOS DE PERMISOS PARA LOS ROLES
	DECLARE @ROLE_PERMISSIONS_GROUP TABLE(
	 [Category] VARCHAR(50),
	 [GroupId]  VARCHAR(200),
	 [Type]     VARCHAR(50)
	)

	INSERT INTO @ROLE_PERMISSIONS_GROUP EXEC [dbo].[GetRolePermissionsGroups] @VCC_SYSTEM

	INSERT INTO [dbo].[RolePermissionsGroup] (
			                              [VCC], 
										  [GroupId], 
										  [Category], 
										  [Type], 
										  [TimeStamp]
										  )
		                                 SELECT 
										 @VCC, 
										 GroupId,
										 Category,
										 [Type], 
										 GETUTCDATE()	
										 FROM @ROLE_PERMISSIONS_GROUP

    --INSERTAR FEELINGS
	INSERT INTO [dbo].[Feeling] (
			                   [VCC], 
							   [Name], 
							   [Description],
							   [CreatedDate], 
							   [CreatedByUserId], 
							   [LastModifiedDate], 
							   [LastModifiedByUserId], 
							   [TimeStamp]
							   )
							   SELECT
							   @VCC,
							   [Name],
							   [Description],
							   GETUTCDATE(),
							   [CreatedByUserId],
							   GETUTCDATE(),
							   [LastModifiedByUserId],
							   GETUTCDATE()	
							   FROM [dbo].[Feeling] (NOLOCK)
							   WHERE [VCC] = @VCC_SYSTEM

    --INSERTAR PROGRAMACION NEUROLINGUISTICA
	INSERT INTO [dbo].[NeuroLinguisticProgramming] (
								[VCC],
								[Name],
								[Description],
								[CreatedDate],
								[CreatedByUserId],
								[LastModifiedDate], 
								[LastModifiedByUserId],
								[TimeStamp]
								)
								SELECT 
								@VCC,
								[Name],
								[Description],
								GETUTCDATE(),
								[CreatedByUserId],
								GETUTCDATE(),
								[LastModifiedByUserId],
								GETUTCDATE()
								FROM [dbo].[NeuroLinguisticProgramming] (NOLOCK)
								WHERE [VCC] = @VCC_SYSTEM
		
   --INSERTAR PALABRAS
   IF(EXISTS(SELECT [Name] FROM [dbo].[Word] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
   BEGIN
		   INSERT INTO [dbo].[Word](
					[VCC],
					[NeuroLinguisticProgrammingId],
					[Name],
					[ProcessId],
					[Language],
					[Type],
					[CreatedDate],
					[CreatedByUserId],
					[LastModifiedDate],
					[LastModifiedByUserId],
					[TimeStamp]
					)
				SELECT
				@VCC,
				[NeuroLinguisticProgrammingId],
				[Name],
				[ProcessId],
				[Language],
				[Type],
				GETUTCDATE(),
				[CreatedByUserId],
				GETUTCDATE(),
				[LastModifiedByUserId],
				GETUTCDATE()
			   FROM [dbo].[Word] (NOLOCK)
			   WHERE [VCC] = @VCC_SYSTEM
   END
   ELSE
   BEGIN
	       RAISERROR('SERVER_ERROR_WORD_NOT_FOUND', 16, 16)
   END

   --INSERTAR CATEGORIAS
   INSERT INTO [dbo].[Category] (
			[VCC], 
			[Name], 
			[Description],
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp]
			)
		SELECT 
		@VCC,
		[Name],
		[Description],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		GETUTCDATE()
	FROM [dbo].[Category] (NOLOCK)
	WHERE [VCC] = @VCC_SYSTEM

	--INSERTAR AMBIENTES
	IF(@Type <> 'OTHER')
	BEGIN
		DECLARE @NAME VARCHAR(100)
		SELECT @NAME = [Word] FROM [dbo].[WordsByLanguage] (NOLOCK) WHERE [Language] = @Language AND [Label] = 'ENVIRONMENT' 
		
		-- DECLARAMOS UNA VARIABLE PARA SETTEAR EL TIPO DE AMBIENTE INTEGRADO PARA EL VCC
		DECLARE @VCC_TYPE VARCHAR(25) = NULL
		IF (@Type = 'ALLEGRO' OR @Type = 'OCC') SET @VCC_TYPE = 'allegro'
		ELSE IF @Type = 'I6' SET @VCC_TYPE = 'i6'
		
		INSERT INTO [dbo].[Environment] (
			[VCC], 
			[Name], 
			[Type],
			[Description],
			[FTPDirectory],
			[ApiHost],
			[ApiPort],
			[ApiUser],
			[DbDisabled],
			[DbServer],
			[DbPort],
			[DbUser], 
			[PbxDisabled],
			[PbxServer],
			[PbxPort],
			[PbxUser],
			[ApiPassword],
			[DbPassword],
			[PbxPassword],
			[CreatedDate],
			[CreatedByUserId],
			[TimeStamp]
		)
			SELECT @VCC,
					@NAME,
					[Type],
					@NAME,
					[FTPDirectory],
					[ApiHost],
					[ApiPort],
					[ApiUser],
					[DbDisabled],
					[DbServer],
					[DbPort],
					[DbUser],
					[PbxDisabled],
					[PbxServer]	,
					[PbxPort],
					[PbxUser],
					[ApiPassword],
					[DbPassword],
					[PbxPassword],
					GETUTCDATE(),
					[CreatedByUserId],
					GETUTCDATE()
				FROM [dbo].[Environment] (NOLOCK)
				WHERE [VCC] = @VCC_SYSTEM
					AND [Type] = @VCC_TYPE

	END


	--INSERTAR PERMISOS PARA CATEGORIAS
	INSERT INTO [dbo].[CategoryPermissions](
			[VCC], 
			[Category], 
			[Position], 
			[TimeStamp]
			)
			SELECT
			@VCC,
		    [Category],
			[Position],
			GETUTCDATE()
			FROM [dbo].[CategoryPermissions] (NOLOCK) 
			WHERE [VCC] = @VCC_SYSTEM
			GROUP BY [Category],[Position]
		  

   --INSERTAR TENANT
   DECLARE @TENANT TABLE(
    [TenantId]     VARCHAR(50),
    [ClientId]     VARCHAR(50),
    [ClientSecret] VARCHAR(50),
    [Resource]     VARCHAR(50)
	)
	
	INSERT INTO @TENANT EXEC [dbo].[GetTenantVCCByVCC] @VCC_SYSTEM
	IF(EXISTS(SELECT [TenantId] FROM @TENANT))
	BEGIN

		INSERT INTO [dbo].[TenantVCC](
		[VCC], 
		[TenantId], 
		[ClientId], 
		[ClientSecret], 
		[Resource], 
		[CreatedDate], 
		[CreatedByUserId], 
		[TimeStamp])
		SELECT 
		@VCC,
		[TenantId],
		[ClientId],
		[ClientSecret],
		[Resource],
		GETUTCDATE(),
		@CreatedByUserId,
		GETUTCDATE()
		FROM @TENANT

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_TENANT_NOT_FOUND', 16, 16)
	END

	--INSERTAR NLU
	IF(EXISTS(SELECT [Name] FROM [dbo].[NLU] WHERE [IsSystemApp]=1 AND [VCC] = @VCC_SYSTEM))
	BEGIN
		INSERT INTO [dbo].[NLU] (
					[VCC], 
					[Name], 
					[Culture],
					[Description], 
					[AppId], 
					[NeedTrain],
					[SubscriptionKey],
					[IsSystemApp], 
					[CreatedDate], 
					[CreatedByUserId], 
					[LastModifiedDate], 
					[LastModifiedByUserId], 
					[TimeStamp],
					[CognitiveEngine]
		)
			SELECT @VCC,
					[Name], 
					[Culture],
					[Description], 
					CONCAT(@VCC,'::',[Name]), 
					-- CASE WHEN [Name] LIKE 'sentiment_%'  THEN 1 ELSE 0 END,
					0, -- ACTUALIZAR CUANDO SE PRENDA NUEVAMENTE EL ANALISIS DE SENTIMIENTOS
					[SubscriptionKey],
					[IsSystemApp], 
					GETUTCDATE(), 
					[CreatedByUserId], 
					GETUTCDATE(), 
					[LastModifiedByUserId], 
					GETUTCDATE(),
					'RASA'
				FROM [dbo].[NLU] (NOLOCK)
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 

		-- INSERTAMOS LOS REGISTROS DE MODELOS DE DIARIZACION
        INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Agent',
					'Agent',
					CONCAT(@VCC,'::',[Name]),
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM
				AND [Name] LIKE 'diarization-%'


		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Positive',
					'Positive',
					CONCAT(@VCC,'::',[Name]),
					'far fa-smile',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
			FROM [dbo].[NLU]
			WHERE [IsSystemApp]=1 
				AND [VCC] = @VCC_SYSTEM 
				AND [Name] LIKE 'sentiment-%'
		 
		INSERT INTO [dbo].[Intent](
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Negative',
					'Negative',
					CONCAT(@VCC,'::',[Name]),
					'far fa-frown',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'
		
		 INSERT INTO [dbo].[Intent] (
			[VCC], 
			[Name],
			[IntentId],
			[AppId],
			[Color],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId], 
			[TimeStamp],
			[Status],
			[StatusCode]
		)
			SELECT @VCC,
					'Neutral',
					'Neutral',
					CONCAT(@VCC,'::',[Name]),
					'far fa-meh',
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					@CreatedByUserId,
					GETUTCDATE(),
					1,
					'AVAILABLE'
				FROM [dbo].[NLU]
				WHERE [IsSystemApp]=1 
					AND [VCC] = @VCC_SYSTEM 
					AND [Name] LIKE 'sentiment-%'
			
			--AGREGAMOS UTTERANCES PARA SENTIMIENTOS.

			INSERT INTO [dbo].[Utterance]( 
			[VCC], 
			[AppId], 
			[IntentId], 
			[Id], 
			[Text], 
			[CreatedDate], 
			[CreatedByUserId], 
			[LastModifiedDate],
			[LastModifiedByUserId], 
			[Status],
			[StatusCode]
			) 
			SELECT @VCC,
			REPLACE(appId,'system',@VCC),
			[IntentId],
			NEWID(),
			[Text],
			GETUTCDATE(),
			'system',
			null,
			null,
			[Status],
			[StatusCode] 
			FROM [dbo].[Utterance]
			WHERE [VCC] =  @VCC_SYSTEM  AND [AppId] LIKE '%sentiment-%'


		-- TODO: CORREGIR PARA REDUCIR 3 INSERT REEMPLAZANDO POR 1 SOLO --
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_SYSTEM_APPS_SAVING_FAILED', 16, 16)
	END

	--INSERTAR DICCIONARIOS
	IF(EXISTS(SELECT [Name] FROM [dbo].[Dictionary] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN 
	INSERT INTO [dbo].[Dictionary] (
			[VCC], 
			[Name], 
			[Description], 
			[Language], 
			[IsSystemDictionary], 
			[CreatedDate], 
			[CreatedByUserId], 
			[TimeStamp]
		)
		SELECT
		    @VCC,
		    [Name],
			[Description],
			[Language],
			[IsSystemDictionary],
			GETUTCDATE(),
			[CreatedByUserId],
			GETUTCDATE()
		FROM [dbo].[Dictionary] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	    RAISERROR('SERVER_ERROR_SYSTEM_DICTIONARIES_SAVING_FAILED',16,16)
	END

	--INSERTAR TIPOS DE INTERACCIONES
	IF(EXISTS(SELECT [ID] FROM [dbo].[InteractionType] WHERE [Instance] = @VCC_SYSTEM ))
	BEGIN
	INSERT INTO [dbo].[InteractionType] (
			[Instance],
			[ID],
			[Description]
			)
			SELECT
			@VCC,
			[ID],
		    [Description]
			FROM InteractionType  (NOLOCK)
			WHERE [Instance] = @VCC_SYSTEM
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_INTERACTION_TYPE_NOT_FOUND',16,16) 
	END

	--INSERTAR GENERIC QUERY
	IF(EXISTS(SELECT [Name] FROM [dbo].[GenericQuery] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [dbo].[GenericQuery]
		(
			[VCC],
			[Name],
			[Description],
			[Query],
			[RawData],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate], 
			[LastModifiedByUserId],
			[Version],
			[TimeStamp]
		)
		SELECT
		@VCC,
		[Name],--REPLACE([Name], @Language+'_', ''),
		[Description],
		[Query],
		[RawData],
		GETUTCDATE(),
		[CreatedByUserId],
		GETUTCDATE(),
		[LastModifiedByUserId],
		[Version],
		GETUTCDATE()
		FROM [dbo].[GenericQuery] (NOLOCK)
		WHERE [VCC] = @VCC_SYSTEM --AND [Name] LIKE @Language + '%'
	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_GENERIC_QUERY_NOT_FOUND',16,16) 
	END

	--INSERTAR  USUARIO AUDITOR SPEECH
	EXEC [dbo].[SaveSpeechAnalyticAuditorUser] @VCC

	--INSERTAR REPORTES
	IF(EXISTS(SELECT [ID] FROM  [dbo].[Report] (NOLOCK) WHERE [VCC] = @VCC_SYSTEM))
	BEGIN
	INSERT INTO [Report] (
			[VCC], 
			[ID], 
			[Description],
			[Type],
            [Procedure], 
			[StartDate],
			[EndDate],
            [Frecuency],
			[HourSpace],
			[ExactTime],
            [Weekday],
			[DayMonth],
			[Summary],
            [Filter], 
			[Email], 
			[CreatedDate],
            [CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
            [TimeStamp]
        )
		SELECT
		        @VCC,
				[ID],
				[Description],
				[Type],
				[Procedure],
				[StartDate],
				[EndDate],
				[Frecuency],
				[HourSpace],
				[ExactTime],
				[Weekday],
				[DayMonth],
				[Summary],
				[Filter],
				[Email],
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE(),
				@CreatedByUserId,
				GETUTCDATE()
			FROM [dbo].[Report] (NOLOCK)
			WHERE [VCC] = @VCC_SYSTEM

	END
	ELSE
	BEGIN
	   RAISERROR('SERVER_ERROR_REPORT_NOT_FOUND',16,16) 
	END

		-- INSERTAMOS LOS GRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[Group] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					G.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[Group] G (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = G.[Description]
				WHERE G.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

		-- INSERTAMOS LOS SUBGRUPOS POR DEFECTO PARA COPC
		INSERT INTO [dbo].[SubGroup] ([Instance], [ID], [Description], [CreatedDate], [CreatedByUserId], [TimeStamp], [Enabled])
			SELECT @VCC,
					SG.[Description],
					WBL.[Word],
					GETUTCDATE(),
					'system',
					GETUTCDATE(),
					1
				FROM [dbo].[SubGroup] SG (NOLOCK)
				INNER JOIN [dbo].[WordsByLanguage] WBL (NOLOCK)
					ON WBL.[Label] = SG.[Description]
				WHERE SG.[Instance] = @VCC_SYSTEM
					AND WBL.[Language] = @Language

	COMMIT TRANSACTION

    END TRY

    BEGIN CATCH

    IF @@TRANCOUNT > 0 
	BEGIN
		ROLLBACK TRANSACTION
		--ELIMINAR LOS REGISTROS SI HA FALLADO
		EXEC [dbo].[RollbackVcc] @VCC
	END

    DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
    DECLARE @Severity integer = ERROR_SEVERITY()
    DECLARE @State integer = ERROR_STATE()

    RAISERROR(@Message, @Severity, @State)
  
    END CATCH
    SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetAgentsFromEvaluation]...';


GO
-- ESTE SP RETORNA LOS AGENTES ASOCIADOS A EVALUACIONES
ALTER PROCEDURE [dbo].[GetAgentsFromEvaluation] 
(
	@VCC					VARCHAR(50) = NULL,
	@UserId					VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
	@SearchType				VARCHAR(50) = NULL,
	@EfectivityMode			BIT = 0 
) 
AS
BEGIN
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_FROM_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER VARCHAR(MAX) = '';
	DECLARE @SQL_FILTER_EFECTIVITY VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';

	-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
	SET @SQL_SELECT += '
		SELECT DISTINCT IEP.[Instance]							''vcc'', 
						IEP.[IdAgent]							''userId''
						-- IEP.[IdCampaign]						''campaignId'' -- NO SE USA APARENTEMENTE (PROBLEMA SAT V.3.7.0) '

	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] '
	SET @SQL_FROM_EFECTIVITY += '
			FROM [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
			INNER JOIN [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
				ON IEP.[Instance] = AEP.[Instance]
					AND IEP.[IdEvaluationPlan] = AEP.[IdEvaluationPlan]
					AND IEP.[IdInteraction] = AEP.[IdInteraction] 
			INNER JOIN (
				SELECT DISTINCT [VCC],
								[InteractionId],
								[AgentId],
								[EvaluationPlanId],
								[AuditorId] 
					FROM [dbo].[EvaluationResultEfectivity] (NOLOCK)
					WHERE [VCC] = ''' + @VCC + ' '' 
						AND [EfectivityStatus] IN (''' + 'CREATED' + '''' + ',' + '''' + 'DRAFT' + ''''+ ')' + '
			) AS ERE ON 
				(AEP.[Instance] = ERE.[VCC] 
					AND AEP.[IdEvaluationPlan] = ERE.[EvaluationPlanId]
					AND AEP.[IdInteraction] = ERE.[InteractionId])'	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @SQL_FILTER += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '
	SET @SQL_FILTER_EFECTIVITY += '
			WHERE AEP.[Instance] = ''' + @VCC + ''' '

	-- ARMAMOS LA PARTE DE EXTRAS
	SET @SQL_EXTRA = '
			ORDER BY IEP.[IdAgent] ASC '

	-- FILTRAMOS SEGUN EL TIPO DE BUSQUEDA
	IF @SearchType = 'PENDING'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE NO HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 0 '
	END
	ELSE IF @SearchType = 'HISTORY'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES QUE YA HAN SIDO EVALUADAS
		SET @SQL_FILTER += '
			AND AEP.[Completed] = 1 '
	END

	-- DECLARAMOS UNA VARIABLE PARA ALMACENAR EL ROLE DEL USUARIO
	DECLARE @USER_ROLE VARCHAR(50) 
	SELECT TOP 1 @USER_ROLE = U.[Role] 
		FROM [dbo].[User] U (NOLOCK) 
		WHERE U.[VCC] = @VCC
			AND U.[ID] = @UserId

	-- FILTRAMOS SEGUN EL ROLE DEL USUARIO
	-- IF @RoleId = 'administrator, quality_admin'
	IF @USER_ROLE = 'quality_auditor'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES AUDITADAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAuditor] = ''' + @UserId + ''' '
		SET @SQL_FILTER_EFECTIVITY += '
			AND ERE.[AuditorId] = ''' + @UserId + ''' '
	END
	ELSE IF @USER_ROLE = 'quality_agent'
	BEGIN
		-- HACEMOS LA BUSQUEDA SOBRE LAS INTERACCIONES HECHAS POR EL USUARIO
		SET @SQL_FILTER += '
			AND AEP.[IdAgent] = ''' + @UserId + ''' '
	END

	-- FILTRAMOS SEGUN EL VALOR DE CAMPAIGNS
	IF @Campaigns IS NOT NULL AND @Campaigns <> ''
	BEGIN
		SET @SQL_FILTER += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
        SET @SQL_FILTER_EFECTIVITY += '
			AND AEP.[IdCampaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	END 

	-- UNIMOS LAS PARTES DEL QUERY
	IF (@EfectivityMode =1)
	SET @SQL_SELECT += @SQL_FROM_EFECTIVITY + @SQL_FILTER_EFECTIVITY + @SQL_EXTRA
	ELSE
	SET @SQL_SELECT += @SQL_FROM + @SQL_FILTER + @SQL_EXTRA
	
	-- EJECUTAMOS LA CONSULTA
	--PRINT @SQL_SELECT
	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetAllegroInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetAllegroInteractions] (
	@Ip						VARCHAR(50),
	@VCC					VARCHAR(50),
	@StartDate				DATETIME = NULL,
	@EndDate				DATETIME = NULL,
	@StartHour				VARCHAR(50),
	@EndHour				VARCHAR(50),
	@Campaign				VARCHAR(MAX),
	@Agent					VARCHAR(MAX),
	@ResultCode				VARCHAR(MAX),
	@Type					INT,
	@Origin					VARCHAR(MAX),
	@MinDuration			INT,
	@MaxDuration			INT,
	@Format					VARCHAR(50) = NULL, 
	@InteractionIds         VARCHAR(MAX) = NULL, 
	@Evaluated              VARCHAR(MAX) = NULL,
	-- @UniqueIds				BIT = 0,							-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO (AUDIOS/INTERACTIONS)
	@ResultType				VARCHAR(50) = NULL,						-- VARIABLE PARA DETERMINAR SI LA BUSQUEDA SERA SOBRE SOBRE DETALLES O ID (DETAILED, SUMMARIZED)
	@ContactAddress			VARCHAR(300) = NULL
) AS
BEGIN
	-- SETTEAMOS UN VALOR POR DEFECTO AL FORMAT
	IF @Format IS NULL OR @Format = '' SET @Format = 'mp3,wav'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- DECLARAMOS UNA VARIABLE PARA IDENTIFICAR SI EL SP ES LLAMADO DEL SISTEMA O POR OTRO SP
	DECLARE @IS_NESTED BIT = 0

	-- CREAMOS LAS VARIABLES QUE HARAN REFERENCIA A LAS TABLAS QUE PUEDEN SER EXTERNAS
	DECLARE @TABLE_HISTORICAL_DATA VARCHAR(50) = ''
	DECLARE @TABLE_MMPRODAT VARCHAR(50) = ''

	-- DECLARAMOS CADENAS PARA EL QUERY FINAL
	--DECLARE @SQL_SELECT_0 VARCHAR(MAX) = ''
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = ''
	DECLARE @SQL_FROM VARCHAR(MAX) = ''
	DECLARE @SQL_EXTRA VARCHAR(MAX) = ''
    DECLARE @FILTERS_OPTIONAL_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = ''
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = ''
	
	DECLARE @Sql NVARCHAR(MAX)

	-- EL TYPE 0 INDICA QUE LAS TABLAS SE ENCUENTRAN EN UN SERVIDOR EXTERNO
	IF(@Type = 0)  
	BEGIN  
		SET @TABLE_HISTORICAL_DATA = '[' + @Ip + ']' + '.[HistoricalData].[dbo].'
		SET @TABLE_MMPRODAT = '[' + @Ip + ']' + '.[MMProDat].[dbo].'
	END
	ELSE IF(@Type = 1) 
	BEGIN
		SET @TABLE_HISTORICAL_DATA = '[HistoricalData].[dbo].'
		SET @TABLE_MMPRODAT = '[MMProDat].[dbo].'
	END
	
	IF(@Type = 0 OR @Type = 1)  
	BEGIN  
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE RESUMEN
		/*SET @SQL_SELECT_0 += '
			SET NOCOUNT ON
			SELECT COUNT(DISTINCT ID.[Id])								''totalInteractions'',
					COUNT(*)											''totalAudios'',
					SUM(ID.[AttentionTime])								''totalAttentionTime'' 
				'*/

		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA DE CONTENIDO
		SET @SQL_SELECT_1 += '
			SET NOCOUNT ON
			SELECT ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)			''ID'',
					ID.[Id]																									''InteractionId'',
					IMP.[Section]																							''Section'',
					IMP.[Part]																								''Part'',
					''CALL''																								''Channel'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''Number'',
					''''																									''Gender'',
					ID.[HoldTime]																							''SilenceTime'',
					ID.[AttentionTime]																						''DurationTime'', -- ESTO SE DEBE CORREGIR
					ID.[AttentionTime]																						''AttentionTime'', -- SE AGREGO CAMPO PARA AMBOS EXISTAN
					ISNULL(CGRM.[Category1], '''')																			''Category1'',
					ISNULL(CGRM.[Category2], '''')																			''Category2'',
					ISNULL(CGRM.[Category3], '''')																			''Category3'',
					ISNULL(CGRM.[Description], '''')																		''Description'',
					ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')															''DispositionCode'',
					ID.[Campaign]																							''Campaign'',
					ID.[LastAgent]																							''Agent'',
					IAD.[ActorName]																							''agentName'',
					ID.[Direction]																							''Type'',
					CONVERT(VARCHAR, ID.[StartDate], 120)																	''StartDate'',
					CONVERT(VARCHAR, ID.[EndDate], 120)																		''EndDate'',
					IMP.[Format]																							''Format'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''ContactAddress'',
					CASE WHEN ID.Direction = ''E'' THEN CID.CallerId ELSE CID.CalledId END									''ContactId'',
					ID.[ContactName]																						''ContactName'',
					IMP.[RelativePath] + ''/'' + IMP.[FileName]															    ''RelativeFileName'',
					RNA = ROW_NUMBER() OVER(PARTITION BY (ID.[Id] + ''_'' + CONVERT(VARCHAR(10), IMP.[Section]) + ''_'' + CONVERT(VARCHAR(10), IMP.Part)) ORDER BY ID.[Id]) -- ROW NUMBER AUDIO
				'

		-- ARMAMOS LA PARTE DE TABLAS 
		SET @SQL_FROM += '
				FROM ' + @TABLE_HISTORICAL_DATA + '[InteractionMultimediaParts] IMP (NOLOCK)
				LEFT JOIN ' + @TABLE_HISTORICAL_DATA + '[InteractionDetail] ID (NOLOCK) 
					ON ID.Id = IMP.Id
				LEFT JOIN ' + @TABLE_HISTORICAL_DATA + '[InteractionActorDetail] IAD (NOLOCK)
					ON IAD.[Id] = ID.[Id]
						AND IAD.[Section] = IMP.[Section]
						AND IAD.[Part] = IMP.[Part]
				LEFT JOIN (
					SELECT VCC, CampaignID, [Order], [Code], 
									[Description], Category1, Category2, Category3 
						FROM ' + @TABLE_MMPRODAT + '[CampaignGoalResultManagement] (NOLOCK)
						WHERE VCC = ''' + @VCC + '''
				) CGRM  
					ON CGRM.VCC = ID.VirtualCC 
						AND CGRM.CampaignId = ID.Campaign 
						AND CGRM.[Description] = ID.ManagementResult
				INNER JOIN ' + @TABLE_HISTORICAL_DATA + '[CallInteractionDetail] CID (NOLOCK) 
					ON ID.Id = CID.Id 
				'

		-- ARMAMOS LA PARTE BASE DE FILTROS
		SET @FILTERS_FIXED_PART = '
				WHERE ID.[VirtualCC] = ''' + @VCC + '''
					AND ID.Id IS NOT NULL '
					
		SET @FILTERS_OPTIONAL_PART = 'AND id.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' 
					AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + '''
					AND IMP.[Format] IN (SELECT Value FROM [dbo].[split](''' + @Format + ''','',''))
					'

		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ID.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) SET @FILTERS_OPTIONAL_PART += 'AND CAST(ID.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
		
		IF(@Campaign IS NOT NULL AND @Campaign <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaign + ''','','')) '

		IF(@Agent IS NOT NULL AND @Agent <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[FirstAgent] IN (SELECT Value FROM [dbo].[split](''' + @Agent + ''','','')) '

		IF(@Origin IS NOT NULL AND @Origin <> '') SET @FILTERS_OPTIONAL_PART += 'AND ID.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origin + ''','','')) '

		IF(@MinDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND ID.[AttentionTime] >= ' + (SELECT CONVERT(varchar(10), @MinDuration)) + ' '

		IF(@MaxDuration IS NOT NULL) SET @FILTERS_OPTIONAL_PART += 'AND ID.[AttentionTime] <= ' + (SELECT CONVERT(varchar(10), @MaxDuration)) + ' '
		
		IF(@ContactAddress IS NOT NULL)
		BEGIN
			SET @FILTERS_OPTIONAL_PART += '
				AND CONCAT(ID.[ContactId], '' '', ID.[ContactName]) LIKE ''%' + @ContactAddress + '%''
			'
		END	

		IF(@ResultCode IS NOT NULL AND @ResultCode <> '') 
			SET @FILTERS_OPTIONAL_PART += 'AND (
									(CONCAT(ID.Campaign, ''_'', ISNULL(CONVERT(VARCHAR(4), CGRM.[Code]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','','')))
									OR
									(ID.[ManagementResult] IN (SELECT Value FROM [dbo].[split](''' + @ResultCode + ''','',''))) 
								) '
	   
		IF @InteractionIds IS NOT NULL AND @InteractionIds <> ''
		BEGIN
			SET @FILTERS_OPTIONAL_PART = '';
			SET @FILTERS_EXCLUDING_PART = ' AND ID.[Id] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
		END 

		SET @SQL_EXTRA = '
			SET NOCOUNT OFF '

		-- UNIMOS LAS PARTES DEL QUERY
		--SET @SQL_SELECT_0 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA
		SET @SQL_SELECT_1 += @SQL_FROM + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA

		-- VERIFICAMOS SI EXISTE LA TABLA TEMPORAL #TMP_HD_INTERACTIONS
		IF OBJECT_ID('TEMPDB..#TMP_HD_INTERACTIONS') IS NULL
		BEGIN
			-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
			CREATE TABLE #TMP_HD_INTERACTIONS
			(
				[ID] VARCHAR(150),
				[InteractionId] VARCHAR(100),
				[Section] INT,
				[Part] INT,
				[Channel] VARCHAR(50),
				[Number] VARCHAR(100),
				[Gender] VARCHAR(50),
				[SilenceTime] INT,
				[DurationTime] INT,
				[AttentionTime] INT,
				[Category1] VARCHAR(100),
				[Category2] VARCHAR(100),
				[Category3] VARCHAR(100),
				[Description] VARCHAR(150),
				[DispositionCode] INT,
				[Campaign] VARCHAR(150),
				[Agent] VARCHAR(100),
				[AgentName] VARCHAR(100),
				[Type] VARCHAR(100),
				[StartDate] VARCHAR(100),
				[EndDate] VARCHAR(100),
				[Format] VARCHAR(50),
				[ContactAddress] VARCHAR(300),
				[ContactId]  VARCHAR(50),
				[ContactName] VARCHAR(300),
				[RelativeFileName] VARCHAR(1000),
				[RNA] INT
			)

			-- REAFIRMAMOS QUE EL SP NO ESTA ANIDADO EN OTRO
			SET @IS_NESTED = 0
		END
		ELSE
		BEGIN
			-- SI LA TABLA TEMPORAL YA EXISTIA, EL SP ESTA ANIDADO EN OTRO (P.E.: [dbo].[GetAsyncBillingInteractions])
			SET @IS_NESTED = 1
		END 
		
		-- EJECUTAMOS EL QUERY Y DEPOSITAMOS EL RESULTADO EN UNA TABLA TEMPORAL
		INSERT INTO #TMP_HD_INTERACTIONS
			-- EJECUTAMOS LA CONSULTA
			EXEC (@SQL_SELECT_1)

		-- VARIABLES PARA TRABAJAR CON LA TABLA TEMPORAL AL FINAL DEL SP
		DECLARE @QUERY_SUMMARY VARCHAR(MAX) = ''
		DECLARE @QUERY_DETAIL VARCHAR(MAX) = ''
		DECLARE @QUERY VARCHAR(MAX) = ''
		DECLARE @QUERY_FILTER VARCHAR(MAX) = ''
		DECLARE @QUERY_JOIN VARCHAR(MAX) = ''
	
		-- FILTRO POR INTERACCIONES EVALUADAS O NO
		IF(@Evaluated IS NOT NULL AND @Evaluated <> '')
		BEGIN 
			DECLARE @EvaluatedTable TABLE (Val BIT)
			INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')
			-- SOLAMENTE SI ES SI O NO
			IF((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
			BEGIN
				IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
				BEGIN 
					SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[InteractionId] AND AEP.[Completed] = 1) '
				END
				ELSE  --Si es No
				BEGIN
					SET @QUERY_JOIN += ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) ON (AEP.[IdInteraction] = HDI.[InteractionId] AND AEP.[Completed] = 1) '
					SET @QUERY_FILTER = ' AND AEP.[IdInteraction] IS NULL '
				END
			END
		END
		-- FIN FILTRO INTERACCIONES EVALUADAS

		-- SI EL SP NO ESTA ANIDADO, HACEMOS SELECT AL RESULTADO A MOSTRAR
		IF @IS_NESTED = 0
		BEGIN
			-- EN AMBOS CASOS SE REQUIERE EL RESUMEN
			SET @QUERY_SUMMARY = '
				SELECT HDI.[channel]										AS ''interactionType'',
						COUNT(DISTINCT (HDI.[InteractionId]))				AS ''interactions'',
						COUNT(DISTINCT (HDI.[ID]))							AS ''details'',
						SUM(HDI.[AttentionTime])							AS ''attentionTime''
					FROM #TMP_HD_INTERACTIONS HDI '
			SET @QUERY +=  @QUERY_SUMMARY + @QUERY_JOIN
			SET @QUERY += ' WHERE HDI.[RNA] = 1 ' + @QUERY_FILTER + ' GROUP BY HDI.[channel] '

			-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
			--IF @ResultType = 'SUMMARIZED'
			--BEGIN
			-- END
			-- ELSE 
			IF @ResultType = 'DETAILED'
			BEGIN
				SET @QUERY_DETAIL = '
					SELECT HDI.* 
						FROM #TMP_HD_INTERACTIONS HDI ' 
				SET @QUERY += @QUERY_DETAIL + @QUERY_JOIN 
				SET @QUERY += ' WHERE HDI.[RNA] = 1 ' + @QUERY_FILTER + ' '
			END

			-- EJECUTAMOS LA CONSULTA
			EXEC (@QUERY)
    
			-- ELIMINAMOS LA TABLA TEMPORARL
			DROP TABLE #TMP_HD_INTERACTIONS
		END
	END
	ELSE
	BEGIN
		SET @Sql = 'SELECT 1 AS ''result'''		
		EXEC (@Sql)
	END

END
GO
PRINT N'Modificando Procedimiento [dbo].[GetAuditorsInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetAuditorsInteractions] (
	@Instance Varchar(50) = NULL, @SearchCriteria Varchar(50) = NULL, @SearchExpression Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

 	SELECT t.ID								'id',
			u.lastname + ' ' + u.Firstname		'name',
			u.Firstname							'firstname',
			u.lastname							'lastname',
			u.email								'email',
			U.[IsLocalSupervisor]				'isLocalSupervisor',
			U.[IsExternalSupervisor]			'isExternalSupervisor',
			U.[IsExternalAgent]					'isExternalAgent',
			t.CreatedDate						'createdDate',
			t.CreatedByUserId					'createdByUserId',
			t.LastModifiedDate					'lastModifiedDate',
			t.LastModifiedByUserId				'lastModifiedByUserId',
			count(1) - sum(CASE WHEN a.Completed=0 THEN 0 ELSE 1 END) 'uncompleteInteractions',
			ISNULL(sum(a.InteractionDuration),0)	'interactionTimeSum'
		FROM [dbo].[Auditor] t (NOLOCK)
		INNER JOIN [dbo].[user] u (NOLOCK)
			ON t.Instance = u.VCC 
				AND t.id = u.ID
		FULL OUTER JOIN [dbo].[AuditorEvaluationPlan] a (NOLOCK)
			ON ( 
				t.Instance = a.Instance 
				AND 
				t.ID = a.IdAuditor
			)
		WHERE t.Instance = @Instance
			AND ISNULL(t.ID, '') LIKE CASE WHEN @SearchCriteria = 'id' THEN '%' + @SearchExpression + '%' ELSE '%' END

			-- SE AGREGA LA VERIFICACION DE QUE EL USER NO SEA NULL PORQUE AL NO EXISTIR EL USUARIO EN LA TABLA USER MUESTRA FILAS CON NULL. SE PRUEBA EN LOS ENDPOINTS: SAVE_USER, DELETE_USER Y EN GET_AUDITORS_INTERACTIONS.
			AND u.[Firstname] IS NOT NULL
			AND u.[LastName] IS NOT NULL
		GROUP BY
			t.ID,
			u.lastname + ' ' + u.Firstname,
			u.Firstname,
			u.lastname,
			u.email,
			U.[IsLocalSupervisor],
			U.[IsExternalSupervisor],
			U.[IsExternalAgent],
			t.CreatedDate,
			t.CreatedByUserId,
			t.LastModifiedDate,
			t.LastModifiedByUserId

 	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetCSVSummaryInteractions]...';


GO
ALTER PROCEDURE [dbo].[GetCSVSummaryInteractions] 
(
	@VCC					VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@MinDuration			INT = 0,
    @MaxDuration			INT = 100000,
    @Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@DispositionCodes		VARCHAR(MAX) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
	--@Evaluated              VARCHAR(MAX) = NULL,
	@IsSummary				BIT = 0								-- ESTE FLAG TIENE COMO PROPOSITO RETORNAR LA LISTA CONSOLIDAD POR IDS O EL TOTAL DEL LISTADO
) 
AS
BEGIN
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NULL OR @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NULL OR @EndHour = '') SET @EndHour = '23:59:59'

	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE MINIMO Y MAXIMO
	IF (@MinDuration IS NULL OR @MinDuration = '') SET @MinDuration = 0
	IF (@MaxDuration IS NULL OR @MaxDuration = '') SET @MaxDuration = 100000
	
	-- DECLARAMOS UN CADENA PARA EL QUERY FINAL
	DECLARE @SQL_SELECT VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_0 VARCHAR(MAX) = '';
	DECLARE @SQL_SELECT_1 VARCHAR(MAX) = '';
	DECLARE @SQL_FROM VARCHAR(MAX) = '';
	DECLARE @SQL_EXTRA VARCHAR(MAX) = '';
    DECLARE @FILTERS_OPTIONAL_PART  VARCHAR(MAX) = '';
    DECLARE @FILTERS_EXCLUDING_PART VARCHAR(MAX) = '';
    DECLARE @FILTERS_FIXED_PART     VARCHAR(MAX) = '';
   -- DECLARE @QUERY_JOIN            VARCHAR(MAX) = '';

	-- HACEMOS EL SELECT SEGUN EL TIPO DE BUSQUEDA SETTEADO
	IF @IsSummary = 1 
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_0 += '
			SELECT ''CALL''											AS ''interactionType'', 
					COUNT(DISTINCT PCT.[ID])						AS ''totalInteractions'',
					COUNT(*)										AS ''details'',
					ISNULL(SUM(PCT.[DurationTime]), 0)				AS ''totalAttentionTime''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_0
	END
	ELSE
	BEGIN
		-- ARMAMOS EL QUERY PARA HACER LA CONSULTA
		SET @SQL_SELECT_1 += '
			SELECT PCT.[ID] + ''_0_0''													''ID'',
					PCT.[ID]															''InteractionId'',
					0																	''Section'',
					0																	''Part'',
					''CALL''															''Channel'',
					PCT.[Number]														''Number'',
					PCT.[Gender]														''Gender'',
					PCT.[SilenceTime]													''SilenceTime'',
					PCT.[DurationTime]													''DurationTime'',
					PCT.[DurationTime]													''AttentionTime'',
					PCT.[Category1]														''Category1'',
					PCT.[Category2]														''Category2'',
					PCT.[Category3]														''Category3'',
					PCT.[Description]													''Description'',
					PCT.[DispositionCode]												''DispositionCode'',
					PCT.[Campaign]														''Campaign'',
					PCT.[Agent]															''Agent'',
					NULL																''agentName'',
					PCT.[Direction]														''Direction'', -- CAMBIAR POR TYPE
					CONVERT(VARCHAR, PCT.[StartDate], 120)								''StartDate'',
					CONVERT(VARCHAR, PCT.[EndDate], 120)								''EndDate'',
					NULL																''Format'',
					PCT.[RelativePath]													''RelativePath'',
					PCT.[RelativeFileName]												''RelativeFileName''
		'

		-- SETTEAMOS EL SELECT A LA VARIABLE FINAL
		SET @SQL_SELECT = @SQL_SELECT_1
	END
	
	-- ARMAMOS LA PARTE DE TABLAS 
	SET @SQL_FROM += ' FROM [#ProcessCsvTemp] PCT '

	-- FILTRO POR INTERACCIONES EVALUADAS O NO
	/*IF(@Evaluated IS NOT NULL AND @Evaluated <> '')
	  BEGIN 
	   DECLARE @EvaluatedTable TABLE (Val BIT)
	   INSERT INTO @EvaluatedTable SELECT Value FROM [dbo].[split]( @Evaluated ,',')
       -- SOLAMENTE SI ES SI O NO
       IF((SELECT COUNT(Val) FROM @EvaluatedTable) = 1 )
       BEGIN
          IF((SELECT Val FROM @EvaluatedTable WHERE Val = 1) IS NOT NULL) -- Si  es Si
           BEGIN 
               SET @QUERY_JOIN = ' JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
           END
          ELSE  --Si es No
           BEGIN
               SET @QUERY_JOIN = ' LEFT JOIN [dbo].[AuditorEvaluationPlan] AEP ON (AEP.[IdInteraction] = PCT.[ID] AND AEP.[Completed]=1 ) '
               SET @FILTERS_OPTIONAL_PART += ' AND AEP.[IdInteraction] IS NULL '
           END
       END
       
	 END*/
	-- FIN FILTRO INTERACCIONES EVALUADAS
	

	-- ARMAMOS LA PARTE DE FILTROS
	SET @FILTERS_FIXED_PART = ' WHERE PCT.[ID] IS NOT NULL ';
    SET @FILTERS_OPTIONAL_PART += '
				AND PCT.[EndDate] BETWEEN ''' + (SELECT CONVERT(VARCHAR(21), @StartDate, 127)) + ''' AND ''' + (SELECT CONVERT(VARCHAR(21), @EndDate, 127)) + ''' 
				AND PCT.[DurationTime] BETWEEN ' + (SELECT CONVERT(VARCHAR(10), @MinDuration)) + ' AND ' + (SELECT CONVERT(VARCHAR(10), @MaxDuration)) + ' ';

	-- CONTINUAMOS CON LOS DEMAS FILTROS RECIBIDOS
	IF (@Campaigns IS NOT NULL AND @Campaigns != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Campaign] IN (SELECT Value FROM [dbo].[split](''' + @Campaigns + ''','','')) '
	
	IF (@Agents IS NOT NULL AND @Agents != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Agent] IN (SELECT Value FROM [dbo].[split](''' + @Agents + ''','','')) '
	
	IF (@Origins IS NOT NULL AND @Origins != '') 
		SET @FILTERS_OPTIONAL_PART += 'AND PCT.[Direction] IN (SELECT Value FROM [dbo].[split](''' + @Origins + ''','','')) '
	
	IF (@DispositionCodes IS NOT NULL AND @DispositionCodes != '') 
		--SET @FILTERS_OPTIONAL_PART += 'AND PCT.[DispositionCode] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')) '
		SET @FILTERS_OPTIONAL_PART += ' 
			AND (
				(CONCAT(PCT.[Campaign], ''_'', ISNULL(CONVERT(VARCHAR(4), PCT.[DispositionCode]), '''')) IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','',''))) 
				OR
				(PCT.[Description] IN (SELECT Value FROM [dbo].[split](''' + @DispositionCodes + ''','','')))
			) '

	-- PARA EL CASO EN QUE HORA DE INICIO Y FIN NO SEAN NULL
	IF @StartHour IS NOT NULL AND @EndHour IS NOT NULL
	BEGIN
		IF (CAST(@StartHour AS TIME) <= CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) BETWEEN ''' + @StartHour + ''' AND ''' + @EndHour + ''' '
		IF (CAST(@StartHour AS TIME) > CAST(@EndHour AS TIME)) 
			SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) NOT BETWEEN ''' + @EndHour + ''' AND ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO NO SEA NULL Y FIN SEA NULL
	ELSE IF @StartHour IS NOT NULL AND @EndHour IS NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) > ''' + @StartHour + ''' '
	END
	-- PARA EL CASO EN QUE HORA DE INICIO SEA NULL Y FIN NO SEA NULL
	ELSE IF @StartHour IS NULL AND @EndHour IS NOT NULL
	BEGIN
		SET @FILTERS_OPTIONAL_PART += 'AND CAST(PCT.[EndDate] AS TIME) < ''' + @EndHour + ''' '
	END

    IF (@InteractionIds IS NOT NULL AND @InteractionIds <> '')
    BEGIN
         SET @FILTERS_OPTIONAL_PART = '';
         --SET @QUERY_JOIN = '';
	     SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] IN (SELECT Value FROM [dbo].[split](''' + @InteractionIds + ''','','')) '
		 -- SET @FILTERS_EXCLUDING_PART = ' AND PCT.[ID] LIKE ''%' + @InteractionIds + '%'' '
	END	  
	-- ELIMINAMOS LA TABLA TEMPORAL DESPUES DE EJECUTAR EL QUERY
	SET @SQL_EXTRA += ' DROP TABLE [#ProcessCsvTemp] '
	
	-- UNIMOS LAS PARTES DEL QUERY
	--SET @SQL_SELECT += @SQL_FROM + @QUERY_JOIN + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA;
    SET @SQL_SELECT += @SQL_FROM  + @FILTERS_FIXED_PART + @FILTERS_OPTIONAL_PART + @FILTERS_EXCLUDING_PART + @SQL_EXTRA;
	-- EJECUTAMOS LA CONSULTA

	EXEC (@SQL_SELECT)
	
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetEvaluationPlanInteractionByTypeAndId]...';


GO
ALTER PROCEDURE [dbo].[GetEvaluationPlanInteractionByTypeAndId] (
	@VCC VARCHAR(50) = NULL,
	@EvaluationPlanId VARCHAR(50) = NULL,
	@InteractionType VARCHAR(50) = NULL,
	@InteractionId VARCHAR(250) = NULL
)
AS
BEGIN
	SET NOCOUNT ON

	-- RECUPERAMOS EL PRIMER REGISTRO POR ID DE INTERACCION
	SELECT TOP 1 IEP.[Instance]											'vcc',
					IEP.[IdAgent]										'descriptionAgent',
					''													'descriptionAuditor',
					IEP.[IdCampaign]									'descriptionCampaign',
					EP.[Description]									'descriptionEvaluationPlan',
					IEP.[InteractionDateStart]							'dateIni',
					IEP.[InteractionDateEnd]							'dateFin',
					IEP.[IdInteraction]									'id',
					IEP.[IdAgent]										'idAgent',
					IEP.[AgentName]										'agentName',
					''													'idAuditorEvaluationPlan',
					IEP.[IdCampaign]									'idCampaign',
					IEP.[IdEvaluationPlan]								'idEvaluationPlan',
					IEP.[InteractionType]								'interactionType',
					IEP.[InteractionDuration]							'interactionTime',
					A.[DurationLinguisticTime]							'interactionValidTime',
					''													'origin',
					IEP.[InteractionMessages]							'totalMessages',
					ISNULL(A.[Number], IEP.[ContactId])					'number',
					IEP.[NeedI6Update]									'needI6Update'
					/*
					IIF (
						E.[Type] = 'i6',
						ISNULL(
							A.[NeedI6Update], 
							CAST(1 AS BIT)	
						),
						CAST(0 AS BIT)
					)													'needI6Update'
					*/

		FROM [dbo].[InteractionEvaluationPlan] IEP (NOLOCK)
		LEFT JOIN [dbo].[EvaluationPlan] EP (NOLOCK) 
			ON EP.[Instance] = IEP.[Instance]
				AND EP.[ID] = IEP.[IdEvaluationPlan]
		LEFT JOIN [dbo].[Environment] E (NOLOCK) 
			ON E.[VCC] = IEP.[Instance]
				AND E.[Name] = EP.[EnvironmentId]
		LEFT JOIN [dbo].[Audio] A (NOLOCK)
			ON A.[VCC] = IEP.[Instance]
				AND A.[ID] = IEP.[IdInteraction]
				AND A.[Section] = IEP.[InteractionSection]
				AND A.[Part] = IEP.[InteractionPart]
		WHERE IEP.[Instance] = @VCC
			AND IEP.[IdEvaluationPlan] = @EvaluationPlanId
			AND IEP.[InteractionType] = @InteractionType
			AND IEP.[IdInteraction] = @InteractionId

	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetProcess]...';


GO
--exec [GetProcess] 'inconcert','test'
ALTER PROCEDURE [dbo].[GetProcess] (
	@VCC Varchar(50) = NULL, @Name Varchar(50) = NULL
	)
AS
BEGIN
	SET NOCOUNT ON

	DECLARE @TOTAL_INTERACTIONS_TO_I6_UPDATE INT = 0
	
	-- CONSULTAMOS CUANTAS INTERACCIONES CALL QUE NECESITAN ACTUALIZACION I6
	SET @TOTAL_INTERACTIONS_TO_I6_UPDATE += (
		SELECT COUNT(*)
			FROM [dbo].[Audio] A (NOLOCK)
			WHERE A.[ID] IN (
				SELECT PA.[AudioId] FROM [dbo].[ProcessAudio] PA WHERE PA.[ProcessId] = @Name
			)
			AND A.[NeedI6Update] = 1
	)

	-- CONSULTAMOS CUANTAS INTERACCIONES TEXT QUE NECESITAN ACTUALIZACION I6
	SET @TOTAL_INTERACTIONS_TO_I6_UPDATE += (
		SELECT COUNT(*)
			FROM [dbo].[AsyncInteraction] AI (NOLOCK)
			WHERE AI.[ID] IN (
				SELECT PAI.[InteractionId] FROM [dbo].[ProcessAsyncInteraction] PAI WHERE PAI.[ProcessId] = @Name
			)
			AND AI.[NeedI6Update] = 1
	)

	-- CONSULTAMOS LA DATA DEL PROCESS
	SELECT P.[VCC]										'vcc',
			P.[Name]									'name',
			P.[Description]								'description',
			P.[ClientId]								'clientId',
			P.[Status]									'status',
			P.[Type]									'type',
			P.[StartDate]								'startDate',
			P.[EndDate]									'endDate',
			P.[MinDurationTime]							'minDurationTime',
			P.[MaxDurationTime]							'maxDurationTime',
			P.[Language]								'language',
			P.[DictionaryId]							'dictionaryId',
			IIF (
				P.[DictionaryId] IS NULL, 
				CONVERT(BIT, 0), 
				CONVERT(BIT, 1)
			)											'useDictionary',
			P.[Environment]								'environment',
			E.[Type]									'environmentType',
			P.[QueryId]									'queryId',
			P.[QueryDataId]								'queryDataId',
			P.[QueryDataIdDate]							'queryDataIdDate',
			P.[BatchScheduleId]							'batchScheduleId',
			IIF (
				@TOTAL_INTERACTIONS_TO_I6_UPDATE > 0,
				CONVERT(BIT, 1), 
				CONVERT(BIT, 0)
			)											'needI6Update',
			P.[CreatedDate]								'createdDate',
			P.[CreatedByUserId]							'createdByUserId',
			P.[LastModifiedDate]						'lastModifiedDate',
			P.[LastModifiedByUserId]					'lastModifiedByUserId'
		FROM [dbo].[Process] P (NOLOCK)
		INNER JOIN [dbo].[Environment] E (NOLOCK)
			ON E.[VCC] = P.[VCC]
				AND E.[Name] = P.[Environment]
		WHERE P.[VCC] = @VCC
			AND P.[Name] = @Name

	EXEC [GetProcessFilters] @VCC, @Name
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[GetTeamPerformanceFilters]...';


GO
ALTER PROCEDURE [dbo].[GetTeamPerformanceFilters] (
	@VCC VARCHAR(50) = NULL,
	@BatchType VARCHAR(50) NULL,
	@EvaluationFormatId VARCHAR(50) NULL,
	@TemplateId VARCHAR(50) NULL

)
AS
BEGIN
	SET NOCOUNT ON
	-- OBTENEMOS LOS FORMATOS DE EVALUACION PARA EL VCC 	
	IF @BatchType = 'EVALUATION_PLAN'
	BEGIN
		SELECT '' 'id','' 'description'
		UNION ALL
		SELECT DISTINCT [ID]  'id', 
						[Description] 'description' 
			FROM [dbo].[EvaluationFormat]
			WHERE [Instance] =  @VCC 

		-- OBTENEMOS LOS PLANES COMPLETADOS
		SELECT DISTINCT EP.[ID]							'id',
						EP.[Description]				'description'
			FROM [dbo].[EvaluationPlan] EP (NOLOCK)
			INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
				ON  EP.[Instance] = AEP.[Instance]
					AND	EP.[ID] = AEP.IdEvaluationPlan
			
			WHERE EP.[Instance] = @VCC
				/*
				AND (
						EP.[Status] = 7 AND EP.Evaluation_Mode = 'A'
						OR
						AEP.[Completed] = 1 AND EP.Evaluation_Mode IN ('X','M')
					)
				*/
				AND AEP.[Completed] = 1
				AND EP.[IdEvaluationFormat] = @EvaluationFormatId
				
		  		

	
		-- OBTENEMOS LOS AGENTES 
		SELECT DISTINCT ER.[IdAgent]							'id',
						ER.[AgentDescription]					'description'
			FROM [dbo].[EvaluationResult] ER (NOLOCK)
			INNER JOIN [dbo].[EvaluationPlan] EP (NOLOCK)
				ON EP.[Instance] = ER.[Instance]
					AND ER.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
			INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK)
				ON EP.[Instance] = AEP.[Instance]
					AND EP.[ID] = AEP.[IdEvaluationPlan]
			WHERE ER.[Instance] = @VCC
				AND (
						EP.[Status] = 7 AND EP.Evaluation_Mode = 'A'
						OR
						AEP.[Completed] = 1 AND EP.Evaluation_Mode IN ('X','M')
					)
				AND ER.[IdEvaluationFormat] = @EvaluationFormatId
		END
		ELSE
		BEGIN

		-- LISTAR TEMPLATES
			
		-- OBTENEMOS LOS ESTUDIOS COMPLETADOS
		SELECT DISTINCT S.[Name]						'id',
						S.[Name]						'name'
			FROM [dbo].[StudyResultSummaryDetail] SRSD (NOLOCK)
			INNER JOIN [dbo].[Study] S (NOLOCK)
				ON S.[VCC] = SRSD.[VCC]
					AND S.[Name] = SRSD.[StudyId]
			WHERE S.[VCC] = @VCC
				AND S.[Type] = 'SPEECH'
				AND S.[Percentage] = 1
				AND S.[TemplateId] = @TemplateId

		END
	
	SET NOCOUNT OFF
END
GO
PRINT N'Modificando Procedimiento [dbo].[ReportByDetailAgent]...';


GO
ALTER PROCEDURE [dbo].[ReportByDetailAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL , 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX), 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
BEGIN
	-- ReportByDetailAgent 'allegro','entrantes','Plan_2_nov01-0356','nov01-0356','20191001','20191201','isidoro','icagente3'
	SET NOCOUNT ON
	
	DECLARE @cols varchar(max) 
	DECLARE @query varchar(max)
  
	-- SETTEAMOS EL STARTDATE Y ENDDATE EN CASO SEAN NULL
	IF @StartDate IS NULL SET @StartDate = '2021-01-01 00:00:00'
	IF @EndDate IS NULL SET @EndDate = '2050-01-01 23:59:59' 
	ELSE 
	BEGIN
		SET @EndDate = DateAdd(hh,- (DatePart(hh, @EndDate)) + 23, @EndDate) 
		SET @EndDate = DateAdd(mi,- (DatePart(mi, @EndDate)) + 59, @EndDate) 
		SET @EndDate = DateAdd(ss,- (DatePart(ss, @EndDate)) + 59, @EndDate) 
	END

	SELECT * 
		INTO #TempEvaluationResult
		FROM (
			SELECT EP.[Instance]														'VCC',
					EP.[Description]													'DescriptionPlan',
					EF.[Description]													'DescriptionFormat',
					(
						GP.[Description]
						+ '-' 
						+ SGP.[Description]
						+ '-' 
						+ A.[Title]
					)																	'Ability', --Collate SQL_Latin1_General_CP1253_CI_AI
					ER.[AgentDescription],
					ER.[CampaignDescription],
					ER.[IdInteraction],
					ISNULL(ER.[Qualification], 0)										'Qualification',
					AEP.[Score]															'Score',
					AEP.[AutomaticScore],
					AEP.[ManualScore],
					--Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss')					AS 'EvaluationDate',
					--CAST(Format(AEP.[TimeStamp], 'yyyy-MM-dd hh:mm:ss') AS DATETIME)					AS 'EvaluationDate',
					AEP.[TimeStamp] AS 'EvaluationDate',
					ER.[IdAuditor],
					EP.[Evaluation_Mode]
				FROM dbo.[EvaluationResult] (NOLOCK) ER
				INNER JOIN dbo.[HistoricEvaluationFormat] EF
					ON EF.[VCC] = ER.[Instance]
						AND EF.[EvaluationPlanId] = ER.[IdEvaluationPlan] 
						AND EF.ID = ER.[IdEvaluationFormat] 
				INNER JOIN dbo.[HistoricAbility] (NOLOCK) A
					ON A.[VCC] = ER.[Instance]
						AND A.[EvaluationPlanId] = ER.[IdEvaluationPlan]  
						AND A.[ID] = ER.[IdAbility] 
				INNER JOIN dbo.[EvaluationPlan] (NOLOCK) EP
					ON EP.[Instance] = ER.[Instance]
						AND EP.[ID] = ER.[IdEvaluationPlan]
				INNER JOIN [dbo].[AuditorEvaluationPlan] AEP (NOLOCK) 
					ON AEP.[Instance] = ER.[Instance]
						AND AEP.[IdEvaluationPlan] =  ER.[IdEvaluationPlan]
						AND AEP.[IdInteraction] = ER.[IdInteraction]
						AND AEP.[IdAuditor] =  ER.[IdAuditor]
				INNER JOIN [HistoricGroup] (NOLOCK) GP
					ON GP.[VCC] = ER.[Instance]
						AND GP.[EvaluationPlanId] = EP.ID
						AND GP.[ID] = ER.[IdGroup] 
				INNER JOIN dbo.[HistoricSubGroup] (NOLOCK) SGP
					ON SGP.[VCC] = ER.[Instance]
						AND SGP.[EvaluationPlanId] = EP.[ID]
						AND SGP.[ID] = ER.[IdSubGroup] 
				WHERE AEP.[TimeStamp] BETWEEN @StartDate AND  @EndDate
					AND AEP.[Completed] = 1
					AND AEP.[StatusDescription] NOT IN('INVALID')
					AND ER.[Instance] LIKE CASE WHEN @VCC IS NOT NULL THEN @VCC ELSE ER.[Instance] END
					AND ER.[AgentDescription] IN (SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL, ER.[AgentDescription], @IdAgente), ','))
					AND ER.[IdAuditor] IN (SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL, ER.[IdAuditor], @IdAuditor), ','))
					AND ER.[CampaignDescription] IN (SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL, ER.[CampaignDescription], @HistoricCampaign), ','))
					AND EP.[Description] IN (SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL, EP.[Description], @Plan), ','))
					AND EF.[Description] IN (SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL, EF.[Description], @Format), ','))
					--AND EP.[Status] = 7
		) A

	-- print 'Despues del select'

	--select * from #TempEvaluationResult ORDER BY IdInteraction

	
	SET @cols = STUFF(
		(
			SELECT (',' + QUOTENAME(TMP_ER.[Ability]))
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')

  --Select @cols
  IF @cols IS NOT NULL
  BEGIN

    DECLARE @type varchar(max)=(Select Top 1 Evaluation_Mode From #TempEvaluationResult)

    DECLARE @Total varchar(max) = STUFF(
		(
			SELECT '+ ISNULL(' + QUOTENAME(TMP_ER.[Ability]) + ',0)'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')

    --SELECT @type
	If @type = 'M'
	BEGIN
    SET @query = ' 
				SELECT p.[VCC]							[VCC],
						p.[DescriptionPlan]				[EVALUATION_PLAN],
						p.[DescriptionFormat]			[EVALUATION_FORMAT],
						p.[AgentDescription]			[AGENT],
  						p.[CampaignDescription]			[CAMPAIGN],
						p.[IdInteraction]				[INTERACTION],
						p.[EvaluationDate]				[EVALUATION_DATE],
						p.[IdAuditor]					[AUDITOR],
						[InteractionDuration]			[DURATION_TIME], 
						NULL							[PHONE],
						[InteractionDateStart]			[START_DATE],
						NULL							[CATEGORY],
						-- (' + @Total + ')				[COLUMN_TOTAL_SCORE], 
						p.[Score]						[COLUMN_TOTAL_SCORE], 
						p.[AutomaticScore]				[COLUMN_AUTOMATIC_SCORE],
						p.[ManualScore]					[COLUMN_MANUAL_SCORE],
						' + @cols + ' 
					FROM 
				( select VCC,
							DescriptionPlan,
							DescriptionFormat,
							Ability,
							AgentDescription,
							CampaignDescription,
							IdInteraction,
							EvaluationDate,
							Qualification,
							Score,
							AutomaticScore,
							ManualScore,
							IdAuditor			
						from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock) 
				) as A On
				A.IdInteraction = p.IdInteraction '
    END
	ELSE 
	BEGIN
    SET @query = ' 
				Select p.[VCC]							[VCC],
						p.[DescriptionPlan]				[EVALUATION_PLAN],
						p.[DescriptionFormat]			[EVALUATION_FORMAT],
						p.[AgentDescription]			[AGENT],
  						p.[CampaignDescription]			[CAMPAIGN] ,
						p.[IdInteraction]				[INTERACTION] ,
						p.[EvaluationDate]				[EVALUATION_DATE],
						p.[IdAuditor]					[AUDITOR],
						A.[DurationTime]				[DURATION_TIME],
						A.[Number]						[PHONE] ,
						A.[StartDate]					[START_DATE] ,
						A.[Category1]					[CATEGORY] ,
						-- (' + @Total + ')				[COLUMN_TOTAL_SCORE], 
						p.[Score]						[COLUMN_TOTAL_SCORE], 
						p.[AutomaticScore]				[COLUMN_AUTOMATIC_SCORE],
						p.[ManualScore]					[COLUMN_MANUAL_SCORE],
						' + @cols + ' 
					from ( 
						select VCC,
								DescriptionPlan,
								DescriptionFormat,
								Ability,
								AgentDescription,
								CampaignDescription,
								IdInteraction,
								EvaluationDate,
								Qualification,
								Score,
								AutomaticScore,
								ManualScore,
								IdAuditor			
							from #TempEvaluationResult
					) x pivot 
					( 
						 max(Qualification)
						for Ability in (' + @cols + ')
					) p 
					LEFT Join Audio as A 
						On A.[VCC] = p.[VCC]
							AND A.ID = p.IdInteraction'
	END
	--Print(@query)
    EXECUTE (@query)
    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] ,
						''			 	As [INTERACTION] ,
						''				As [EVALUATION_DATE],
						''				As [AUDITOR]
  END
  
  SET NOCOUNT OFF

END
GO
PRINT N'Modificando Procedimiento [dbo].[ReportBySummaryAgent]...';


GO


ALTER PROCEDURE [dbo].[ReportBySummaryAgent] (
	@VCC varchar(50) = NULL, 
	@HistoricCampaign varchar(MAX) = NULL, 
	@Plan varchar(MAX) = NULL,
	@Format varchar(MAX) , 
	@StartDate DateTime = NULL , 
	@EndDate DateTime = NULL , 
	@IdAuditor varchar(MAX) = NULL ,
	@IdAgente varchar(MAX) = NULL
) AS
  DECLARE @cols varchar(max)
  DECLARE @query varchar(max)
  --ReportBySummaryAgent 'allegro','entrantes',NULL,'nov01-0356',NULL,NULL,NULL,NULL
  --SET @Format = 'nov01-0356'
  SET NOCOUNT ON
  
  SELECT
    * INTO #TempEvaluationResult
  FROM (
  SELECT
    EP.Description AS 'DescriptionPlan',
    EF.Description AS 'DescriptionFormat',
    GP.Description + '-' + SGP.Description + '-' + A.Title AS 'Ability',
    ER.AgentDescription,
    ER.CampaignDescription,
    ER.IdInteraction,
    ER.Qualification,
    Format(ER.EvaluationDate, 'dd/MM/yyyy hh:mm:ss') AS 'EvaluationDate',
    ER.IdAuditor,
    EP.Evaluation_Mode
  FROM EvaluationResult (NOLOCK) ER
  LEFT JOIN HistoricEvaluationFormat (NOLOCK) EF
    ON ER.IdEvaluationFormat = EF.ID AND ER.IdEvaluationPlan = EF.EvaluationPlanId
  LEFT JOIN HistoricAbility (NOLOCK) A
    ON A.ID = ER.IdAbility AND ER.IdEvaluationPlan = A.EvaluationPlanId
  LEFT JOIN EvaluationPlan (NOLOCK) EP
    ON EP.ID = ER.IdEvaluationPlan
  LEFT JOIN [HistoricGroup] (NOLOCK) GP
    ON GP.ID = ER.IdGroup AND EP.ID = GP.EvaluationPlanId
  LEFT JOIN HistoricSubGroup SGP (NOLOCK)
    ON SGP.ID = ER.IdSubGroup AND EP.ID = SGP.EvaluationPlanId
  WHERE 
   EF.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Format IS NULL,EF.Description,@Format),','))
  AND ER.Instance LIKE CASE
    WHEN @VCC IS NOT NULL THEN @VCC
    ELSE ER.Instance
  END
  AND 
  EP.Description IN(SELECT [Value] FROM [dbo].[Split](IIF(@Plan IS NULL,EP.Description,@Plan),','))
  AND
  ER.CampaignDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@HistoricCampaign IS NULL,ER.CampaignDescription,@HistoricCampaign),','))
  AND 
  ER.AgentDescription IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAgente IS NULL,ER.AgentDescription,@IdAgente),','))
  AND 
  ER.IdAuditor IN(SELECT [Value] FROM [dbo].[Split](IIF(@IdAuditor IS NULL,ER.IdAuditor,@IdAuditor),','))
  AND ER.EvaluationDate >=
                          CASE
                            WHEN @StartDate IS NOT NULL THEN @StartDate
                            ELSE '19800101'
                          END
  AND ER.EvaluationDate <
                         CASE
                           WHEN @EndDate IS NOT NULL THEN @EndDate + ' 23:59'
                           ELSE '20500101'
                         END
	) a

	
	SET @cols = STUFF(
		(
			SELECT (',' + QUOTENAME(TMP_ER.[Ability]))
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
  
  IF @cols IS NOT NULL
  BEGIN
    ------
    DECLARE @type varchar(max) = (SELECT TOP 1
      Evaluation_Mode
    FROM #TempEvaluationResult)
	
	-------
    DECLARE @Total varchar(max) = STUFF(
		(
			SELECT '+ ISNULL(' + QUOTENAME(TMP_ER.[Ability]) + ',0)'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')    
	
	-- ROUND(AVG(CAST(ER.Qualification AS float)), 2) AS 'Qualification',
    DECLARE @colavg varchar(max) = STUFF(
		(
			SELECT ', ROUND(AVG(CAST(q.' + QUOTENAME(TMP_ER.[Ability]) + ' AS float)), 2) As [' + TMP_ER.[Ability] + ' Promedio]'
				FROM #TempEvaluationResult TMP_ER
				GROUP BY TMP_ER.[Ability] 
				ORDER BY TMP_ER.[Ability] 
			FOR xml PATH (''), TYPE
		).value('.', 'varchar(Max)')
		, 1, 1, '')
	
	--SELECT @colavg
    IF @type = 'M'
    BEGIN
      SET @query = ' 
				Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
				count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + ' From
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,InteractionDuration as DurationTime, 
				null As Number,InteractionDateStart As StartDate,null As Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join (
				Select Distinct IdInteraction,InteractionDuration,InteractionDateStart From InteractionEvaluationPlan (Nolock)
				) as A On
				A.IdInteraction=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription
				'
    END
    ELSE
    BEGIN
      SET @query = '
	
			    Select 
				q.DescriptionPlan As   [EVALUATION_PLAN] ,
				q.DescriptionFormat As [EVALUATION_FORMAT] ,
				q.AgentDescription As  [AGENT] ,
				q.CampaignDescription As [CAMPAIGN] ,
			    count(q.IdInteraction) As [AUDITS],
				sum(q.DurationTime) As [DURATION_TIME],
				ROUND(AVG(CAST(q.Note AS float)), 2) As [AVERAGE_SCORE],
				' + @colavg + '
				From 
				(Select p.DescriptionPlan,p.DescriptionFormat,p.AgentDescription,
  				p.CampaignDescription,p.IdInteraction,p.EvaluationDate,p.IdAuditor,
				A.DurationTime,A.Number,A.StartDate,A.Category1,(' + @Total + ') As Note, ' + @cols + ' from 
				( select DescriptionPlan,
						  DescriptionFormat,
						  Ability,
						  AgentDescription,
						  CampaignDescription,
						  IdInteraction,
						  EvaluationDate,
						  Qualification,
						  IdAuditor			
					from #TempEvaluationResult
			   ) x
				pivot 
				( 
					 max(Qualification)
					for Ability in (' + @cols + ')
				) p 
				Left Join Audio as A On
				A.ID=p.IdInteraction)q
				Group By 
				q.DescriptionPlan,q.DescriptionFormat,q.AgentDescription,q.CampaignDescription'
    END
    --Print(@query)
    EXECUTE (@query)
    --Select * From @query
	

    DROP TABLE #TempEvaluationResult
  END
  ELSE
  BEGIN
    DROP TABLE #TempEvaluationResult
    SELECT
						''				As [EVALUATION_PLAN],
						''				As [EVALUATION_FORMAT],
						''				As [AGENT],
  						''			    As [CAMPAIGN] 
  END
  
  SET NOCOUNT OFF
GO
PRINT N'Actualizando Procedimiento [dbo].[SaveVcc]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[SaveVcc]';


GO
PRINT N'Actualizando Procedimiento [dbo].[GetFiltersFromEvaluation]...';


GO
EXECUTE sp_refreshsqlmodule N'[dbo].[GetFiltersFromEvaluation]';


GO
PRINT N'Actualización completada.';


GO
